@@ -296,6 +296,14 @@ QList<QTextLayout::FormatRange> KateRenderer::decorationsForLine( const KateText
   if (selectionsOnly || textLine->attributesList().count() || m_view->externalHighlights().count() || m_view->internalHighlights().count() || m_doc->documentHighlights().count()) {
     RenderRangeList renderRanges;
 
+    // Add the inbuilt highlighting to the list
+    NormalRenderRange* inbuiltHighlight = new NormalRenderRange();
+    const QVector<int> &al = textLine->attributesList();
+    for (int i = 0; i+2 < al.count(); i += 3) {
+      inbuiltHighlight->addRange(new KTextEditor::Range(KTextEditor::Cursor(line, al[i]), al[i+1]), specificAttribute(al[i+2]));
+    }
+    renderRanges.append(inbuiltHighlight);
+
     if (!completionHighlight) {
       // Add arbitrary highlighting ranges to the list
       renderRanges.appendRanges(m_view->internalHighlights(), selectionsOnly, view());
@@ -307,14 +315,6 @@ QList<QTextLayout::FormatRange> KateRenderer::decorationsForLine( const KateText
       renderRanges.append(completionHighlight);
     }
 
-    // Add the inbuilt highlighting to the list
-    NormalRenderRange* inbuiltHighlight = new NormalRenderRange();
-    const QVector<int> &al = textLine->attributesList();
-    for (int i = 0; i+2 < al.count(); i += 3) {
-      inbuiltHighlight->addRange(new KTextEditor::Range(KTextEditor::Cursor(line, al[i]), al[i+1]), specificAttribute(al[i+2]));
-    }
-    renderRanges.append(inbuiltHighlight);
-
     // Add selection highlighting if we're creating the selection decorations
     if ((selectionsOnly && showSelections() && m_view->selection()) || (completionHighlight && completionSelected) || m_view->blockSelection()) {
       NormalRenderRange* selectionHighlight = new NormalRenderRange();
@@ -480,8 +480,6 @@ void KateRenderer::paintTextLine(QPainter& paint, KateLineLayoutPtr range, int x
       KateTextLayout line = range->viewLine(i);
 
       // Determine the background to use, if any, for the end of this view line
-//       QBrush backgroundBrush;
-//       bool backgroundBrushSet = false;
       backgroundBrushSet = false;
       while (it2.hasNext()) {
         const QTextLayout::FormatRange& fr = it2.peekNext();
@@ -520,19 +518,25 @@ void KateRenderer::paintTextLine(QPainter& paint, KateLineLayoutPtr range, int x
       backgroundDetermined:
 
       // Draw selection outside of areas where text is rendered
-      if (m_view->selection() && !m_view->blockSelection() && m_view->lineEndSelected(line.end(true))) {
-        QRect area(line.endX() + line.xOffset() - xStart, fm.height() * i, xEnd - xStart, fm.height() * (i + 1));
-        paint.fillRect(area, config()->selectionColor());
+      if (!m_printerFriendly ) {
+        if (m_view->selection() && !m_view->blockSelection() && m_view->lineEndSelected(line.end(true))) {
+          int width= xEnd - xStart;
+          int height= fm.height() * (i + 1);
+          int fillStartX = line.endX() - line.startX() + line.xOffset() - xStart;
+          int fillStartY = fm.height() * i;
+ 
+          QRect area(fillStartX, fillStartY, width, height);
+          paint.fillRect(area, config()->selectionColor());
 
-      } else if (backgroundBrushSet && !m_view->blockSelection()) {
-        // Draw text background outside of areas where text is rendered.
-        QRect area(line.endX() /*+ line.xOffset()*/ - line.startX() +  (i==0?0:range->shiftX()) - xStart/*-(i*xEnd)*/, fm.height() * i, xEnd - xStart, fm.height() /** (i + 1)*/);
-        paint.fillRect(area, /*QBrush(Qt::red));*/backgroundBrush);
-//         kDebug()<<i<<":backgroundBrush:"<<backgroundBrush<<"---"<<xEnd<<"/"<<xStart;
-//         kDebug()<<line.endX()<<"---"<<line.xOffset();
-         kDebug()<<i<<"----"<<area;
+        } else if (backgroundBrushSet && !m_view->blockSelection()) {
+          // Draw text background outside of areas where text is rendered.
+          QRect area(line.endX() /*+ line.xOffset()*/ - line.startX() +  (i==0?0:range->shiftX()) - xStart/*-(i*xEnd)*/, fm.height() * i, xEnd - xStart, fm.height() /** (i + 1)*/);
+          paint.fillRect(area, /*QBrush(Qt::red));*/backgroundBrush);
+  //         kDebug()<<i<<":backgroundBrush:"<<backgroundBrush<<"---"<<xEnd<<"/"<<xStart;
+  //         kDebug()<<line.endX()<<"---"<<line.xOffset();
+          //kDebug()<<i<<"----"<<area;
+        }
       }
-
       // Draw indent lines
       if (showIndentLines() && i == 0)
       {
@@ -581,7 +585,7 @@ void KateRenderer::paintTextLine(QPainter& paint, KateLineLayoutPtr range, int x
         paint.fillRect(0, fm.height(), range->shiftX() - xStart, fm.height() * (range->viewLineCount() - 1),
           backgroundBrush);
       paint.fillRect(0, fm.height(), range->shiftX() - xStart, fm.height() * (range->viewLineCount() - 1),
-        QBrush(config()->wordWrapMarkerColor(), Qt::DiagCrossPattern));
+        QBrush(config()->wordWrapMarkerColor(), Qt::Dense4Pattern));
     }
 
     // Draw caret
@@ -602,16 +606,21 @@ void KateRenderer::paintTextLine(QPainter& paint, KateLineLayoutPtr range, int x
 
       QColor c;
       // Could actually use the real highlighting system for this... would be slower but more accurate for corner cases
-      foreach (QTextLayout::FormatRange r, range->layout()->additionalFormats())
-        if ( (r.start <= cursor->column() ) && ( (r.start + r.length)  > cursor->column()) ) {
-          c = r.format.foreground().color();
-          break;
-        }
-      if (!c.isValid())
-        if (range->layout()->additionalFormats().count())
-          c = range->layout()->additionalFormats().last().format.foreground().color();
-        else
-          c = attribute(KateExtendedAttribute::dsNormal)->foreground().color();
+      if (m_caretOverrideColor.isValid()) {
+        c = m_caretOverrideColor;
+
+      } else {
+        foreach (QTextLayout::FormatRange r, range->layout()->additionalFormats())
+          if ( (r.start <= cursor->column() ) && ( (r.start + r.length)  > cursor->column()) ) {
+            c = r.format.foreground().color();
+            break;
+          }
+        if (!c.isValid())
+          if (range->layout()->additionalFormats().count())
+            c = range->layout()->additionalFormats().last().format.foreground().color();
+          else
+            c = attribute(KateExtendedAttribute::dsNormal)->foreground().color();
+      }
 
       if (cursor->column() <= range->length()) {
         paint.save();
@@ -634,64 +643,6 @@ void KateRenderer::paintTextLine(QPainter& paint, KateLineLayoutPtr range, int x
     }
   }
 
-  /* Remnants from the old implementation which haven't yet been integrated into the new
-  {
-    bool isIMSel  = false;
-    bool isIMEdit = false;
-
-    while (curCol - startcol < len)
-    {
-      // Only draw after the starting X value
-      if ((int)xPosAfter >= xStart)
-      {
-        // input method edit area
-        isIMEdit = m_view && m_view->isIMEdit( line, curCol );
-
-        // input method selection
-        isIMSel = m_view && m_view->isIMSelection( line, curCol );
-
-          // indentation lines OR
-          || (showIndentLines() && curCol < lastIndentColumn)
-
-          // input method edit area
-          || ( m_view && (isIMEdit != m_view->isIMEdit( line, nextCol )) )
-
-          // input method selection
-          || ( m_view && (isIMSel !=  m_view->isIMSelection( line, nextCol )) )
-
-            if (isIMSel && !isTab)
-            {
-              // input method selection
-              fillColor = m_view->colorGroup().color(QPalette::Foreground);
-            }
-            else if (isIMEdit && !isTab)
-            {
-              // XIM support
-              // input method edit area
-              const QColorGroup& cg = m_view->colorGroup();
-              int h1, s1, v1, h2, s2, v2;
-              cg.color( QPalette::Base ).getHsv( &h1, &s1, &v1 );
-              cg.color( QPalette::Background ).getHsv( &h2, &s2, &v2 );
-              fillColor.setHsv( h1, s1, ( v1 + v2 ) / 2 );
-            }
-
-            if (isIMSel && paintBackground && !isTab)
-            {
-              paint.save();
-              paint.setPen( m_view->colorGroup().color( QPalette::BrightText ) );
-            }
-
-            // Draw preedit's underline
-            if (isIMEdit) {
-              QRect r( oldXPos - xStart, 0, xPosAfter - oldXPos, config()->fontMetrics().height() );
-              paint.drawLine( r.bottomLeft(), r.bottomRight() );
-            }
-
-            // Put pen color back
-            if (isIMSel) paint.restore();
-    }
-  */
-
   // show word wrap marker if desirable
   if ((!isPrinterFriendly()) && config()->wordWrapMarker() && QFontInfo(config()->font()).fixedPitch())
   {
@@ -899,4 +850,9 @@ KTextEditor::Cursor KateRenderer::xToCursor(const KateTextLayout & range, int x,
   return ret;
 }
 
+void KateRenderer::setCaretOverrideColor(const QColor& color)
+{
+  m_caretOverrideColor = color;
+}
+
 // kate: space-indent on; indent-width 2; replace-tabs on;
