@@ -371,7 +371,7 @@ int KateHlFloat::checkHgl(const QString& text, int offset, int len)
   if (!b)
     return 0;
 
-  if ((len > 0) && (text[offset].toAscii() == 'E'))
+  if ((len > 0) && ((text[offset].toAscii() & 0xdf) == 'E'))
   {
     offset++;
     len--;
@@ -456,7 +456,7 @@ int KateHlCOct::checkHgl(const QString& text, int offset, int len)
 
     if (offset2 > offset)
     {
-      if ((len > 0) && (text[offset2].toAscii() == 'L' || text[offset].toAscii() == 'U' ))
+      if ((len > 0) && ((text[offset2].toAscii() & 0xdf) == 'L' || (text[offset].toAscii() & 0xdf) == 'U' ))
         offset2++;
 
       return offset2;
@@ -476,13 +476,13 @@ KateHlCHex::KateHlCHex(int attribute, KateHlContextModification context,signed c
 
 int KateHlCHex::checkHgl(const QString& text, int offset, int len)
 {
-  if ((len > 1) && (text[offset++].toAscii() == '0') && (text[offset++].toAscii() == 'X' ))
+  if ((len > 1) && (text[offset++].toAscii() == '0') && ((text[offset++].toAscii() & 0xdf) == 'X' ))
   {
     len -= 2;
 
     int offset2 = offset;
 
-    while ((len > 0) && (text[offset2].isDigit() || (text[offset2].toAscii() >= 'A' && text[offset2].toAscii() <= 'F')))
+    while ((len > 0) && (text[offset2].isDigit() || ((text[offset2].toAscii() & 0xdf) >= 'A' && (text[offset2].toAscii() & 0xdf) <= 'F')))
     {
       offset2++;
       len--;
@@ -490,7 +490,7 @@ int KateHlCHex::checkHgl(const QString& text, int offset, int len)
 
     if (offset2 > offset)
     {
-      if ((len > 0) && (text[offset2].toAscii() == 'L' || text[offset2].toAscii() == 'U' ))
+      if ((len > 0) && ((text[offset2].toAscii() & 0xdf) == 'L' || (text[offset2].toAscii() & 0xdf) == 'U' ))
         offset2++;
 
       return offset2;
@@ -529,7 +529,7 @@ int KateHlCFloat::checkHgl(const QString& text, int offset, int len)
 
   if (offset2)
   {
-    if (text[offset2].toAscii() == 'F' )
+    if ((text[offset2].toAscii() & 0xdf) == 'F' )
       offset2++;
 
     return offset2;
@@ -538,7 +538,7 @@ int KateHlCFloat::checkHgl(const QString& text, int offset, int len)
   {
     offset2 = checkIntHgl(text, offset, len);
 
-    if (offset2 && (text[offset2].toAscii() == 'F' ))
+    if (offset2 && ((text[offset2].toAscii() & 0xdf) == 'F' ))
       return ++offset2;
     else
       return 0;
@@ -671,9 +671,7 @@ static int checkEscapedChar(const QString& text, int offset, int& len)
         for (i = 0; (len > 0) && (i < 2); i++)
         {
           const char ch = text[offset].toAscii();
-          if (((ch >= '0') && (ch <= '9'))
-              || ((ch >= 'a') && (ch <= 'f'))
-              || ((ch >= 'A') && (ch <= 'F'))) {
+          if (((ch >= '0') && (ch <= '9')) || (((ch & 0xdf) >= 'A') && ((ch & 0xdf) <= 'F'))) {
             offset++;
             len--;
           } else {
