@@ -90,9 +90,6 @@ class KateView : public KTextEditor::View,
 
     QString viewMode () const;
 
-    void setDestructing() { m_destructing = true; }
-    inline bool destructing() {return m_destructing;}
-
   //
   // KTextEditor::ClipboardInterface
   //
@@ -115,7 +112,6 @@ class KateView : public KTextEditor::View,
 
   // helper to export text as html stuff
   private:
-    bool m_destructing;
     QString selectionAsHtml ();
     QString textAsHtml ( KTextEditor::Range range, bool blockwise);
     void textAsHtmlStream ( const KTextEditor::Range& range, bool blockwise, QTextStream *ts);
@@ -274,10 +270,6 @@ class KateView : public KTextEditor::View,
     const QList<KTextEditor::SmartRange*>& actions() const;
     void clearActions();
 
-    // For the document to pass new document-level highlighting ranges in
-    void addHighlightRange(KTextEditor::SmartRange* range);
-    void removeHighlightRange(KTextEditor::SmartRange* range);
-
   Q_SIGNALS:
     void dynamicHighlightAdded(KateSmartRange* range);
     void dynamicHighlightRemoved(KateSmartRange* range);
@@ -522,8 +514,8 @@ class KateView : public KTextEditor::View,
     void setupCodeFolding();
 
     KActionCollection*     m_editActions;
-    QAction*               m_editUndo;
-    QAction*               m_editRedo;
+    KAction*               m_editUndo;
+    KAction*               m_editRedo;
     KRecentFilesAction*    m_fileRecent;
     KToggleAction*         m_toggleFoldingMarkers;
     KToggleAction*         m_toggleIconBar;
@@ -532,7 +524,7 @@ class KateView : public KTextEditor::View,
     KToggleAction*         m_toggleDynWrap;
     KSelectAction*         m_setDynWrapIndicators;
     KToggleAction*         m_toggleWWMarker;
-    QAction*               m_switchCmdLine;
+    KAction*               m_switchCmdLine;
 
     KSelectAction*         m_setEndOfLine;
 
@@ -591,19 +583,17 @@ class KateView : public KTextEditor::View,
    * IM input stuff
    */
   public:
-    void setIMSelectionValue( const KTextEditor::Range& imRange, const KTextEditor::Range& imSelection, bool imComposeEvent );
-    const KTextEditor::Range& imSelection() const;
-    const KTextEditor::Range& imEdit() const;
+    void setImComposeEvent( bool imComposeEvent ) { m_imComposeEvent = imComposeEvent; }
     bool imComposeEvent () const { return m_imComposeEvent; }
 
-  ///Template stuff
-  virtual bool insertTemplateTextImplementation ( const KTextEditor::Cursor&, const QString &templateString, const QMap<QString,QString> &initialValues);
-
-
   private:
-    KTextEditor::Range m_imRange, m_imSelection;
     bool m_imComposeEvent;
 
+  ///Template stuff
+  public:
+    virtual bool insertTemplateTextImplementation ( const KTextEditor::Cursor&, const QString &templateString, const QMap<QString,QString> &initialValues);
+
+
   /**
    * Accessors to the bars...
    */
