@@ -301,6 +301,7 @@ KConfig* KConfig::copyTo(const QString &file, KConfig *config) const
     const KEntryMapIterator theEnd = config->d_func()->entryMap.end();
     for (KEntryMapIterator it = config->d_func()->entryMap.begin(); it != theEnd; ++it)
         it->bDirty = true;
+    config->d_ptr->bDirty = true;
 
     return config;
 }
@@ -566,7 +567,7 @@ void KConfig::deleteGroupImpl(const QByteArray &aGroup, WriteConfigFlags flags)
 
     bool dirty = false;
     foreach (const QByteArray& group, groups) {
-        const QStringList keys = keyList(group);
+        const QStringList keys = keyList(QString::fromUtf8(group));
         foreach (const QString& key, keys) {
             if (d->canWriteEntry(group, key.toUtf8().constData())) {
                 d->entryMap.setEntry(group, key.toUtf8(), QByteArray(), options);
