@@ -167,8 +167,8 @@ class KCmdLineArgsStatic {
 
     int argc; // The original argc
     char **argv; // The original argv
-    bool parsed; // Whether we have parsed the arguments since calling init
-    bool ignoreUnknown; // Ignore unknown options and arguments
+    bool parsed : 1; // Whether we have parsed the arguments since calling init
+    bool ignoreUnknown : 1; // Ignore unknown options and arguments
     QString mCwd; // Current working directory. Important for KUnqiueApp!
     KCmdLineArgs::StdCmdLineArgs mStdargs;
 
@@ -531,7 +531,7 @@ KCmdLineArgs::saveAppArgs( QDataStream &ds)
    s->removeArgs("qt");
    s->removeArgs("kde");
 
-   QString qCwd = QFile::encodeName(s->mCwd);
+   QByteArray qCwd = QFile::encodeName(s->mCwd);
    ds << qCwd;
 
    uint count = s->argsList ? s->argsList->count() : 0;
@@ -681,6 +681,8 @@ KCmdLineArgsStatic::findOption(const KCmdLineOptions &options, QString &opt,
                int p = nextOption.indexOf(' ');
                if (p > 0)
                   nextOption = nextOption.left(p);
+               if (nextOption.startsWith('!'))
+                  nextOption = nextOption.mid(1);
                if (nextOption.startsWith("no"))
                {
                   nextOption = nextOption.mid(2);
@@ -914,10 +916,7 @@ KCmdLineArgsStatic::parseAllArgs()
            if (s->about->bugAddress().isEmpty() || s->about->bugAddress() == "submit@bugs.kde.org" )
              s->printQ( i18n( "Please use http://bugs.kde.org to report bugs.\n" ) );
            else {
-             if( s->about->authors().count() == 1 && s->about->authors().first().emailAddress() == s->about->bugAddress() )
-               s->printQ( i18n( "Please report bugs to %1.\n" ,  s->about->authors().first().emailAddress() ) );
-             else
-               s->printQ( i18n( "Please report bugs to %1.\n" , s->about->bugAddress()) );
+             s->printQ( i18n( "Please report bugs to %1.\n" , s->about->bugAddress()) );
            }
          }
          else
