@@ -21,6 +21,8 @@
 
 #include <kdecore_export.h>
 #include <QtCore/QAtomicPointer>
+#include <sys/types.h>
+
 
 //
 // WARNING!!
@@ -353,6 +355,12 @@ namespace KGlobal
      */
     KDECORE_EXPORT KCharsets *charsets();
 
+    /**
+     * Returns the umask of the process.
+     * @return the umask of the process
+     */
+    KDECORE_EXPORT mode_t umask();
+
     /**
      * Creates a static QString.
      *
