@@ -869,7 +869,6 @@ void KConfigTest::testConfigCopyTo()
         KConfigGroup group2(&cf2, "CopyToTest");
         QString testVal = group2.readEntry("Type");
         QCOMPARE(testVal, QString("Test"));
-        group2.writeEntry("AnotherKey", "Test Worked"); // for sync to have something to sync
         cf2.sync();
         QVERIFY(QFile::exists(destination));
     }
@@ -879,7 +878,6 @@ void KConfigTest::testConfigCopyTo()
     KConfigGroup group3(&cf3, "CopyToTest");
     QString testVal = group3.readEntry("Type");
     QCOMPARE(testVal, QString("Test"));
-    QCOMPARE(group3.readEntry("AnotherKey"), QString("Test Worked"));
 }
 
 void KConfigTest::testKAboutDataOrganizationDomain()
@@ -928,3 +926,12 @@ void KConfigTest::testCreateDir()
     QVERIFY(QFile::exists(file));
 }
 
+void KConfigTest::testSyncOnExit()
+{
+    // Often, the KGlobalPrivate global static's destructor ends up calling ~KConfig ->
+    // KConfig::sync ... and if that code triggers KGlobal code again then things could crash.
+    // So here's a test for modifying KGlobal::config() and not syncing, the process exit will sync.
+    KConfigGroup grp(KGlobal::config(), "syncOnExit");
+    grp.writeEntry("key", "value");
+}
+
