@@ -169,10 +169,10 @@ QObject *KPluginFactory::create(const char *iface, QWidget *parentWidget, QObjec
         return obj;
     }
 
-    QList<KPluginFactoryPrivate::Plugin> canidates(d->createInstanceHash.values(keyword));
+    const QList<KPluginFactoryPrivate::Plugin> candidates(d->createInstanceHash.values(keyword));
     // for !keyword.isEmpty() candidates.count() is 0 or 1
 
-    foreach (const KPluginFactoryPrivate::Plugin &plugin, canidates) {
+    foreach (const KPluginFactoryPrivate::Plugin &plugin, candidates) {
         for (const QMetaObject *current = plugin.first; current; current = current->superClass()) {
             if (0 == qstrcmp(iface, current->className())) {
                 if (obj) {
@@ -219,12 +219,9 @@ QStringList KPluginFactory::variantListToStringList(const QVariantList &list)
 
 QVariantList KPluginFactory::stringListToVariantList(const QStringList &list)
 {
-    QStringList copy(list);
     QVariantList variantlist;
-
-    while (!copy.isEmpty())
-        variantlist << QVariant(copy.takeFirst());
-
+    Q_FOREACH(const QString& str, list)
+        variantlist << QVariant(str);
     return variantlist;
 }
 
