@@ -21,6 +21,7 @@
  */
 #include "kconfigdialog.h"
 
+#include <kcomponentdata.h>
 #include <kconfigdialogmanager.h>
 #include <kconfigskeleton.h>
 #include <kdebug.h>
@@ -68,6 +69,7 @@ KConfigDialog::KConfigDialog( QWidget *parent, const QString& name,
   setCaption( i18n("Configure") );
   setFaceType( List );
   setButtons( Default|Ok|Apply|Cancel|Help );
+  setHelp( QString(), KGlobal::mainComponent().componentName() );
   setDefaultButton( Ok );
   setObjectName( name );
 
@@ -150,7 +152,8 @@ KPageWidgetItem* KConfigDialog::KConfigDialogPrivate::addPageInternal(QWidget *p
 
   KPageWidgetItem *item = new KPageWidgetItem( frame, itemName );
   item->setHeader( header );
-  item->setIcon( KIcon( pixmapName ) );
+  if ( !pixmapName.isEmpty() )
+    item->setIcon( KIcon( pixmapName ) );
 
   q->KPageDialog::addPage( item );
   return item;
