@@ -144,8 +144,9 @@ public:
      * context menus.
      *
      * @return the key that pops up context menus.
+     * @deprecated Simply reimplement QWidget::contextMenuEvent() instead.
      */
-    static int contextMenuKey ();
+    static KDE_DEPRECATED int contextMenuKey ();
 
     /**
      * Returns the KDE setting for context menus.
@@ -426,7 +427,6 @@ public:
      * The layout scheme to use for dialog buttons
      *
      * @return Returns the number of the scheme to use.
-     * @see KDialog::setButtonStyle
      */
     static int buttonLayout();
 
@@ -435,10 +435,11 @@ public:
      *
      * This is only useful for configuration modules such as krdb and should not be
      * used in normal circumstances.
+     * @param config KConfig from which to load the colors (passed as-is to
+     * ::KColorScheme).
      *
      * @return the QPalette
      */
-    // TODO should the parameter be documented, or should it be hidden from doxygen?
     static QPalette createApplicationPalette(const KSharedConfigPtr &config = KSharedConfigPtr());
 
     /**
