@@ -242,7 +242,7 @@ void KPageViewPrivate::updateTitleWidget(const QModelIndex& index)
         header = model->data( index, Qt::DisplayRole ).toString();
     }
 
-    titleWidget->setText( header.remove( '&' ) );
+    titleWidget->setText( header );
 
     const QIcon icon = model->data( index, Qt::DecorationRole ).value<QIcon>();
     titleWidget->setPixmap( icon.pixmap( 22, 22 ) );
