@@ -44,10 +44,12 @@ public:
     };
 };
 
+#ifndef KDE_USE_FINAL // already defined in kfontchooser.cpp
 static bool localeLessThan (const QString &a, const QString &b)
 {
     return QString::localeAwareCompare(a, b) < 0;
 }
+#endif
 
 KTimeZoneWidget::KTimeZoneWidget( QWidget *parent, KTimeZones *db )
   : QTreeWidget( parent ),
