@@ -874,10 +874,11 @@ void KDirOperator::setUrl(const KUrl& _newurl, bool clearforward)
     else
         newurl = _newurl;
 
+    newurl.adjustPath( KUrl::AddTrailingSlash );
 #ifdef Q_WS_WIN
     QString pathstr = newurl.toLocalFile();
 #else
-    QString pathstr = newurl.path(KUrl::AddTrailingSlash);
+    QString pathstr = newurl.path();
 #endif
     newurl.setPath(pathstr);
 
