@@ -680,14 +680,19 @@ bool CSSParser::parseValue( int propId, bool important )
         break;
 
     case CSS_PROP_CURSOR:
-        //  [ auto | crosshair | default | pointer | progress | move | e-resize | ne-resize |
-        // nw-resize | n-resize | se-resize | sw-resize | s-resize | w-resize | text |
-        // wait | help ] ] | inherit
+        //  [ auto | default | none |
+	//  context-menu | help | pointer | progress | wait | 
+	//  cell | crosshair | text | vertical-text | 
+	//  alias | copy | move | no-drop | not-allowed | 
+	//  e-resize | ne-resize | nw-resize | n-resize | se-resize | sw-resize | s-resize | w-resize |
+	//  ew-resize | ns-resize | nesw-resize | nwse-resize |
+	//  col-resize | row-resize | all-scroll 
+        // ] ] | inherit
     // MSIE 5 compatibility :/
         if ( !strict && id == CSS_VAL_HAND ) {
             id = CSS_VAL_POINTER;
             valid_primitive = true;
-        } else if ( id >= CSS_VAL_AUTO && id <= CSS_VAL_HELP )
+        } else if (( id >= CSS_VAL_AUTO && id <= CSS_VAL_ALL_SCROLL ) || id == CSS_VAL_NONE )
             valid_primitive = true;
         break;
 
