@@ -22,12 +22,13 @@
 
 #include <QDockWidget>
 
-namespace KJS
-{
-    class DebugDocument;
-}
-
 class QTableWidget;
+class QTableWidgetItem;
+
+namespace KJSDebugger {
+class DebugDocument;
+struct InterpreterContext;
+
 class CallStackDock : public QDockWidget
 {
     Q_OBJECT
@@ -35,11 +36,17 @@ public:
     CallStackDock(QWidget *parent = 0);
     ~CallStackDock();
 
-    void displayStack(KJS::DebugDocument *document);
-
+    void displayStack(InterpreterContext* ctx);
+    void clearDisplay();
+private slots:
+    void slotViewItem(QTableWidgetItem* item);
+signals:
+    void displayScript(KJSDebugger::DebugDocument* doc, int line);
 private:
+    InterpreterContext* m_activeCtx;
     QTableWidget *m_view;
-    KJS::DebugDocument *m_current;
 };
 
+}
+
 #endif
