@@ -587,13 +587,13 @@ JSValue* DOMNodeProtoFunc::callAsFunction(ExecState *exec, JSObject *thisObj, co
       return jsBoolean(node.isSupported(args[0]->toString(exec).domString(),args[1]->toString(exec).domString()));
     case DOMNode::AddEventListener: {
         JSEventListener *listener = Window::retrieveActive(exec)->getJSEventListener(args[1]);
-        int id = EventImpl::typeToId(args[0]->toString(exec).domString());
+        EventName id = EventName::fromString(args[0]->toString(exec).domString());
         node.addEventListener(id,listener,args[2]->toBoolean(exec));
         return jsUndefined();
     }
     case DOMNode::RemoveEventListener: {
         JSEventListener *listener = Window::retrieveActive(exec)->getJSEventListener(args[1]);
-        int id = EventImpl::typeToId(args[0]->toString(exec).domString());
+        EventName id = EventName::fromString(args[0]->toString(exec).domString());
         node.removeEventListener(id,listener,args[2]->toBoolean(exec));
         return jsUndefined();
     }
@@ -616,8 +616,8 @@ JSValue* DOMNodeProtoFunc::callAsFunction(ExecState *exec, JSObject *thisObj, co
     case DOMNode::InsertBefore:
       return getDOMNode(exec,node.insertBefore(toNode(args[0]), toNode(args[1]), exception));
     case DOMNode::ReplaceChild: {
-      SharedPtr<DOM::NodeImpl> oldKid = toNode(args[0]);
-      node.replaceChild(oldKid.get(), toNode(args[1]), exception);
+      SharedPtr<DOM::NodeImpl> oldKid = toNode(args[1]);
+      node.replaceChild(toNode(args[0]), oldKid.get(), exception);
       return getDOMNode(exec, oldKid.get());
     }
     case DOMNode::Contains:
@@ -915,6 +915,7 @@ const ClassInfo DOMDocument::info = { "Document", &DOMNode::info, &DOMDocumentTa
   readyState      DOMDocument::ReadyState                      DontDelete|ReadOnly
   defaultView     DOMDocument::DefaultView                     DontDelete|ReadOnly
   async           DOMDocument::Async                           DontDelete
+  title           DOMDocument::Title                           DontDelete
 @end
 */
 
@@ -985,6 +986,8 @@ JSValue* DOMDocument::getValueProperty(ExecState *exec, int token) const
     }
   case Async:
     return jsBoolean(doc.async());
+  case Title:
+    return jsString(doc.title());
   default:
     kDebug(6070) << "WARNING: DOMDocument::getValueProperty unhandled token " << token;
     return jsNull();
@@ -1011,6 +1014,11 @@ void DOMDocument::putValueProperty(ExecState *exec, int token, JSValue* value, i
       doc.setAsync(value->toBoolean(exec));
       break;
     }
+    case Title: {
+      DOM::DOMString val = value->toString(exec).domString();
+      if (doc.title() != val) doc.setTitle(val);
+      break;
+    }
   }
 }
 
@@ -1876,11 +1884,16 @@ JSValue* DOMCharacterDataProtoFunc::callAsFunction(ExecState *exec, JSObject *th
 
 // -------------------------------------------------------------------------
 
-const ClassInfo DOMText::info = { "Text",
-				 &DOMCharacterData::info, 0, 0 };
+const ClassInfo DOMText::info = { "Text", &DOMCharacterData::info,
+                                  &DOMTextTable , 0 };
+
 /*
-@begin DOMTextProtoTable 1
-  splitText	DOMText::SplitText	DontDelete|Function 1
+@begin DOMTextTable 2
+  wholeText        DOMText::WholeText        DontDelete|ReadOnly
+@end
+@begin DOMTextProtoTable 2
+  splitText	   DOMText::SplitText	     DontDelete|Function 1
+  replaceWholeText DOMText::ReplaceWholeText DontDelete|Function 1
 @end
 */
 KJS_DEFINE_PROTOTYPE_WITH_PROTOTYPE(DOMTextProto, DOMCharacterDataProto)
@@ -1893,7 +1906,22 @@ DOMText::DOMText(ExecState *exec, DOM::TextImpl* t)
   setPrototype(DOMTextProto::self(exec));
 }
 
+bool DOMText::getOwnPropertySlot(ExecState* exec,
+                                 const Identifier& propertyName,
+                                 PropertySlot& slot)
+{
+    return getStaticValueSlot<DOMText, DOMCharacterData>(exec, &DOMTextTable, this, propertyName, slot);
+}
 
+JSValue* DOMText::getValueProperty(ExecState*, int token) const
+{
+    TextImpl* text = static_cast<TextImpl*>(impl());
+    switch (token) {
+    case WholeText:
+        return jsString(text->wholeText());
+    }
+    return jsNull(); // not reached
+}
 
 JSValue* DOMTextProtoFunc::callAsFunction(ExecState *exec, JSObject *thisObj, const List &args)
 {
@@ -1903,6 +1931,8 @@ JSValue* DOMTextProtoFunc::callAsFunction(ExecState *exec, JSObject *thisObj, co
   switch(id) {
     case DOMText::SplitText:
       return getDOMNode(exec,text.splitText(args[0]->toInteger(exec), exception));
+    case DOMText::ReplaceWholeText:
+      return getDOMNode(exec, text.replaceWholeText(args[0]->toString(exec).domString(), exception));
     default:
       break;
   }
