@@ -39,15 +39,13 @@
 #include <khtml_part.h>
 #include <sys/utsname.h>
 
-#include <Qt3Support/Q3PtrList>
-
 using namespace KJS;
 
 namespace KJS {
 
     // All objects that need plugin info must inherit from PluginBase
     // Its ctor and dtor take care of the refcounting on the static lists.
-    class PluginBase : public ObjectImp {
+    class PluginBase : public JSObject {
     public:
         PluginBase(ExecState *exec, bool loadPluginInfo);
         virtual ~PluginBase();
@@ -66,11 +64,11 @@ namespace KJS {
             QString name;
             QString file;
             QString desc;
-            Q3PtrList<MimeClassInfo> mimes;
+            QList<const MimeClassInfo*> mimes;
         };
 
-        static Q3PtrList<PluginInfo> *plugins;
-        static Q3PtrList<MimeClassInfo> *mimes;
+        static QList<const PluginInfo*> *plugins;
+        static QList<const MimeClassInfo*> *mimes;
 
     private:
         static int m_refCount;
@@ -84,14 +82,14 @@ namespace KJS {
             m_pluginsEnabled(pluginsEnabled) {}
 
         virtual bool getOwnPropertySlot(ExecState *exec, const Identifier& propertyName, PropertySlot& slot);
-        ValueImp *getValueProperty(ExecState *exec, int token) const;
+        JSValue *getValueProperty(ExecState *exec, int token) const;
         virtual const ClassInfo* classInfo() const { return &info; }
         static const ClassInfo info;
-        static ValueImp *pluginByName( ExecState* exec, const QString& name );
+        static JSValue *pluginByName( ExecState* exec, const QString& name );
         bool pluginsEnabled() const { return m_pluginsEnabled; }
     private:
-        static ValueImp *indexGetter(ExecState *, JSObject*, const Identifier&, const PropertySlot&);
-        static ValueImp *nameGetter(ExecState *, JSObject*, const Identifier&, const PropertySlot&);
+        static JSValue *indexGetter(ExecState *, JSObject*, const Identifier&, const PropertySlot&);
+        static JSValue *nameGetter(ExecState *, JSObject*, const Identifier&, const PropertySlot&);
         bool m_pluginsEnabled;
     };
 
@@ -104,53 +102,53 @@ namespace KJS {
         virtual bool getOwnPropertySlot(ExecState *exec, const Identifier& propertyName, PropertySlot& slot);
         virtual const ClassInfo* classInfo() const { return &info; }
         static const ClassInfo info;
-        ValueImp *getValueProperty(ExecState *exec, int token) const;
-        static ValueImp *mimeTypeByName( ExecState* exec, const QString& name );
+        JSValue *getValueProperty(ExecState *exec, int token) const;
+        static JSValue *mimeTypeByName( ExecState* exec, const QString& name );
         bool pluginsEnabled() const { return m_pluginsEnabled; }
     private:
-        static ValueImp *indexGetter(ExecState *, JSObject*, const Identifier&, const PropertySlot&);
-        static ValueImp *nameGetter(ExecState *, JSObject*, const Identifier&, const PropertySlot&);
+        static JSValue *indexGetter(ExecState *, JSObject*, const Identifier&, const PropertySlot&);
+        static JSValue *nameGetter(ExecState *, JSObject*, const Identifier&, const PropertySlot&);
         bool m_pluginsEnabled;
     };
 
 
     class Plugin : public PluginBase {
     public:
-        Plugin( ExecState *exec, PluginBase::PluginInfo *info )
+        Plugin(ExecState *exec, const PluginBase::PluginInfo *info)
           : PluginBase( exec, true )
         { m_info = info; }
         virtual bool getOwnPropertySlot(ExecState *exec, const Identifier& propertyName, PropertySlot& slot);
         virtual const ClassInfo* classInfo() const { return &info; }
         static const ClassInfo info;
-        ValueImp *mimeByName(ExecState* exec, const QString& name ) const;
-        ValueImp *getValueProperty(ExecState *exec, int token) const;
-        PluginBase::PluginInfo *pluginInfo() const { return m_info; }
+        JSValue *mimeByName(ExecState* exec, const QString& name ) const;
+        JSValue *getValueProperty(ExecState *exec, int token) const;
+        const PluginBase::PluginInfo *pluginInfo() const { return m_info; }
     private:
-        PluginBase::PluginInfo *m_info;
-        static ValueImp *indexGetter(ExecState *, JSObject*, const Identifier&, const PropertySlot&);
-        static ValueImp *nameGetter(ExecState *, JSObject*, const Identifier&, const PropertySlot&);
+        const PluginBase::PluginInfo *m_info;
+        static JSValue *indexGetter(ExecState *, JSObject*, const Identifier&, const PropertySlot&);
+        static JSValue *nameGetter(ExecState *, JSObject*, const Identifier&, const PropertySlot&);
     };
 
 
     class MimeType : public PluginBase {
     public:
-        MimeType( ExecState *exec, PluginBase::MimeClassInfo *info )
+        MimeType(ExecState *exec, const PluginBase::MimeClassInfo *info)
           : PluginBase( exec, true )
         { m_info = info; }
         virtual bool getOwnPropertySlot(ExecState *exec, const Identifier& propertyName, PropertySlot& slot);
         virtual const ClassInfo* classInfo() const { return &info; }
         static const ClassInfo info;
-        ValueImp *getValueProperty(ExecState *exec, int token) const;
+        JSValue *getValueProperty(ExecState *exec, int token) const;
     private:
-        PluginBase::MimeClassInfo *m_info;
+        const PluginBase::MimeClassInfo *m_info;
     };
 
 }
 
 
-Q3PtrList<PluginBase::PluginInfo> *KJS::PluginBase::plugins = 0;
-Q3PtrList<PluginBase::MimeClassInfo> *KJS::PluginBase::mimes = 0;
-int KJS::PluginBase::m_refCount = 0;
+QList<const PluginBase::PluginInfo*> *KJS::PluginBase::plugins;
+QList<const PluginBase::MimeClassInfo*> *KJS::PluginBase::mimes;
+int KJS::PluginBase::m_refCount;
 
 const ClassInfo Navigator::info = { "Navigator", 0, &NavigatorTable, 0 };
 /*
@@ -168,6 +166,7 @@ const ClassInfo Navigator::info = { "Navigator", 0, &NavigatorTable, 0 };
   mimeTypes	Navigator::_MimeTypes	DontDelete|ReadOnly
   product	Navigator::Product	DontDelete|ReadOnly
   vendor	Navigator::Vendor	DontDelete|ReadOnly
+  vendorSub	Navigator::VendorSub	DontDelete|ReadOnly
   productSub    Navigator::ProductSub   DontDelete|ReadOnly
   cookieEnabled	Navigator::CookieEnabled DontDelete|ReadOnly
   javaEnabled	Navigator::JavaEnabled	DontDelete|Function 0
@@ -176,60 +175,66 @@ const ClassInfo Navigator::info = { "Navigator", 0, &NavigatorTable, 0 };
 KJS_IMPLEMENT_PROTOFUNC(NavigatorFunc)
 
 Navigator::Navigator(ExecState *exec, KHTMLPart *p)
-  : ObjectImp(exec->lexicalInterpreter()->builtinObjectPrototype()), m_part(p) { }
+  : JSObject(exec->lexicalInterpreter()->builtinObjectPrototype()), m_part(p) { }
 
 bool Navigator::getOwnPropertySlot(ExecState *exec, const Identifier& propertyName, PropertySlot& slot)
 {
 #ifdef KJS_VERBOSE
   kDebug(6070) << "Navigator::getOwnPropertySlot " << propertyName.ascii();
 #endif
-  return getStaticPropertySlot<NavigatorFunc, Navigator, ObjectImp>(exec, &NavigatorTable, this, propertyName, slot);
+  return getStaticPropertySlot<NavigatorFunc, Navigator, JSObject>(exec, &NavigatorTable, this, propertyName, slot);
 }
 
-ValueImp *Navigator::getValueProperty(ExecState *exec, int token) const
+JSValue *Navigator::getValueProperty(ExecState *exec, int token) const
 {
   KUrl url = m_part->url();
-  QString userAgent = url.host();
-  if (userAgent.isEmpty())
-     userAgent = "localhost";
-  userAgent = KProtocolManager::userAgentForHost(userAgent);
+  QString host = url.host();
+  if (host.isEmpty())
+     host = "localhost";
+  QString userAgent  = KProtocolManager::userAgentForHost(host);
+// ### get the following from the spoofing UA files as well.
+  QString appName = "Netscape";
+  QString product = "Gecko";
+  QString productSub = "20030107";
+  QString vendor = "KDE";
+  QString vendorSub = "";
+
   switch (token) {
   case AppCodeName:
-    return String("Mozilla");
+    return jsString("Mozilla");
   case AppName:
     // If we find "Mozilla" but not "(compatible, ...)" we are a real Netscape
     if (userAgent.indexOf(QLatin1String("Mozilla")) >= 0 &&
         userAgent.indexOf(QLatin1String("compatible")) == -1)
     {
       //kDebug() << "appName -> Mozilla";
-      return String("Netscape");
+      return jsString("Netscape");
     }
     if (userAgent.indexOf(QLatin1String("Microsoft")) >= 0 ||
         userAgent.indexOf(QLatin1String("MSIE")) >= 0)
     {
       //kDebug() << "appName -> IE";
-      return String("Microsoft Internet Explorer");
+      return jsString("Microsoft Internet Explorer");
     }
-    //kDebug() << "appName -> Konqueror";
-    return String("Konqueror");
+    //kDebug() << "appName -> Default";
+    return jsString(appName);
   case AppVersion:
     // We assume the string is something like Mozilla/version (properties)
-    return String(userAgent.mid(userAgent.indexOf('/') + 1));
+    return jsString(userAgent.mid(userAgent.indexOf('/') + 1));
   case Product:
     // We are pretending to be Mozilla or Safari
     if (userAgent.indexOf(QLatin1String("Mozilla")) >= 0 &&
         userAgent.indexOf(QLatin1String("compatible")) == -1)
     {
-        return String("Gecko");
+        return jsString("Gecko");
     }
-    // When spoofing as IE, we use Undefined().
+    // When spoofing as IE, we use jsUndefined().
     if (userAgent.indexOf(QLatin1String("Microsoft")) >= 0 ||
         userAgent.indexOf(QLatin1String("MSIE")) >= 0)
     {
-        return Undefined();
+        return jsUndefined();
     }
-    // We are acting straight
-    return String("Konqueror/khtml");
+    return jsString(product);
   case ProductSub:
     {
       int ix = userAgent.indexOf("Gecko");
@@ -237,69 +242,69 @@ ValueImp *Navigator::getValueProperty(ExecState *exec, int token) const
           userAgent.indexOf(QRegExp("\\d{8}"), ix+6) == ix+6)
       {
           // We have Gecko/<productSub> in the UA string
-          return String(userAgent.mid(ix+6, 8));
-      }
-      else if (ix >= 0)
-      {
-          return String("20040107");
+          return jsString(userAgent.mid(ix+6, 8));
       }
     }
-    return Undefined();
+    return jsString(productSub);
   case Vendor:
-    return String("KDE");
+    if (userAgent.indexOf(QLatin1String("Safari")) >= 0)
+    {
+        return jsString("Apple Computer, Inc.");
+    }
+    return jsString(vendor);
+  case VendorSub:
+    return jsString(vendorSub);
   case BrowserLanguage:
   case Language:
   case UserLanguage:
-    return String(KGlobal::locale()->language());
+    return jsString(KGlobal::locale()->language());
   case UserAgent:
-    return String(userAgent);
+    return jsString(userAgent);
   case Platform:
     // yet another evil hack, but necessary to spoof some sites...
     if ( (userAgent.indexOf(QLatin1String("Win"),0,Qt::CaseInsensitive)>=0) )
-      return String("Win32");
+      return jsString("Win32");
     else if ( (userAgent.indexOf(QLatin1String("Macintosh"),0,Qt::CaseInsensitive)>=0) ||
               (userAgent.indexOf(QLatin1String("Mac_PowerPC"),0,Qt::CaseInsensitive)>=0) )
-      return String("MacPPC");
+      return jsString("MacPPC");
     else
     {
         struct utsname name;
         int ret = uname(&name);
         if ( ret >= 0 )
-            return String(QString::fromLatin1("%1 %1 X11").arg(name.sysname).arg(name.machine));
+            return jsString(QString::fromLatin1("%1 %2").arg(name.sysname).arg(name.machine));
         else // can't happen
-            return String("Unix X11");
+            return jsString("Unix X11");
     }
   case CpuClass:
   {
     struct utsname name;
     int ret = uname(&name);
     if ( ret >= 0 )
-      return String(name.machine);
+      return jsString(name.machine);
     else // can't happen
-      return String("x86");
+      return jsString("unknown");
   }
   case _Plugins:
     return new Plugins(exec, m_part->pluginsEnabled());
   case _MimeTypes:
     return new MimeTypes(exec, m_part->pluginsEnabled());
   case CookieEnabled:
-    return Boolean(true); /// ##### FIXME
+    return jsBoolean(true); /// ##### FIXME
   default:
     kDebug(6070) << "WARNING: Unhandled token in DOMEvent::getValueProperty : " << token;
-    return Null();
+    return jsNull();
   }
 }
 
 /*******************************************************************/
 
 PluginBase::PluginBase(ExecState *exec, bool loadPluginInfo)
-  : ObjectImp(exec->lexicalInterpreter()->builtinObjectPrototype() )
+  : JSObject(exec->lexicalInterpreter()->builtinObjectPrototype() )
 {
     if ( loadPluginInfo && !plugins ) {
-        plugins = new Q3PtrList<PluginInfo>;
-        mimes = new Q3PtrList<MimeClassInfo>;
-        plugins->setAutoDelete( true );
-        mimes->setAutoDelete( true );
+        plugins = new QList<const PluginInfo*>;
+        mimes = new QList<const MimeClassInfo*>;
 
         // read in using KServiceTypeTrader
         const KService::List offers = KServiceTypeTrader::self()->query("Browser/View");
@@ -316,20 +321,21 @@ PluginBase::PluginBase(ExecState *exec, bool loadPluginInfo)
                     continue;
             }
             // read configuration
-            KConfigGroup kc = KSharedConfig::openConfig( KStandardDirs::locate ("data", pluginsinfo.toString()) )->group( "0" );
-            const int num = kc.readEntry("number", 0);
+            QString fn = KStandardDirs::locate("data", pluginsinfo.toString());
+            const KSharedConfig::Ptr sc = KSharedConfig::openConfig(fn);
+            const int num = sc->group("").readEntry("number", 0);
             for ( int n = 0; n < num; n++ ) {
-                kc.changeGroup( QString::number(n) );
+                const KConfigGroup kc = sc->group(QString::number(n));
                 PluginInfo *plugin = new PluginInfo;
 
                 plugin->name = kc.readEntry("name");
-                plugin->file = kc.readPathEntry("file");
+                plugin->file = kc.readPathEntry("file", QString());
                 plugin->desc = kc.readEntry("description");
 
                 plugins->append( plugin );
 
-                QStringList types = kc.readEntry("mime", QStringList(), ';');
-                QStringList::Iterator type;
+                const QStringList types = kc.readXdgListEntry("mime");
+                QStringList::const_iterator type;
                 for ( type=types.begin(); type!=types.end(); ++type ) {
 
                     // get mime information
@@ -366,6 +372,10 @@ PluginBase::~PluginBase()
 {
     m_refCount--;
     if ( m_refCount==0 ) {
+        if (plugins)
+            qDeleteAll(*plugins);
+        if (mimes)
+            qDeleteAll(*mimes);
         delete plugins;
         delete mimes;
         plugins = 0;
@@ -387,21 +397,21 @@ const ClassInfo Plugins::info = { "PluginArray", 0, &PluginsTable, 0 };
 */
 KJS_IMPLEMENT_PROTOFUNC(PluginsFunc)
 
-ValueImp *Plugins::getValueProperty(ExecState *exec, int token) const
+JSValue *Plugins::getValueProperty(ExecState*, int token) const
 {
   assert(token == Plugins_Length);
   if (pluginsEnabled())
-    return Number(plugins->count());
+    return jsNumber(plugins->count());
   else
-    return Number(0);
+    return jsNumber(0);
 }
 
-ValueImp *Plugins::indexGetter(ExecState *exec, JSObject*, const Identifier& propertyName, const PropertySlot& slot)
+JSValue *Plugins::indexGetter(ExecState* exec, JSObject*, const Identifier& /*propertyName*/, const PropertySlot& slot)
 {
   return new Plugin(exec, plugins->at(slot.index()));
 }
 
-ValueImp *Plugins::nameGetter(ExecState *exec, JSObject*, const Identifier& propertyName, const PropertySlot& slot)
+JSValue *Plugins::nameGetter(ExecState* exec, JSObject*, const Identifier& propertyName, const PropertySlot& /*slot*/)
 {
   return pluginByName(exec, propertyName.qstring());
 }
@@ -418,14 +428,15 @@ bool Plugins::getOwnPropertySlot(ExecState *exec, const Identifier &propertyName
     // plugins[#]
     bool ok;
     unsigned int i = propertyName.toUInt32(&ok);
-    if (ok && i < plugins->count()) {
+    if (ok && i < static_cast<unsigned>(plugins->count())) {
       slot.setCustomIndex(this, i, indexGetter);
       return true;
     }
 
     // plugin[name]
-    for (PluginInfo *pl = plugins->first(); pl; pl = plugins->next()) {
-      if (pl->name == propertyName.qstring()) {
+    QList<const PluginInfo*>::const_iterator it, end = plugins->constEnd();
+    for (it = plugins->constBegin(); it != end; ++it) {
+      if ((*it)->name == propertyName.qstring()) {
         slot.setCustom(this, nameGetter);
         return true;
       }
@@ -435,16 +446,17 @@ bool Plugins::getOwnPropertySlot(ExecState *exec, const Identifier &propertyName
   return PluginBase::getOwnPropertySlot(exec, propertyName, slot);
 }
 
-ValueImp *Plugins::pluginByName( ExecState* exec, const QString& name )
+JSValue *Plugins::pluginByName( ExecState* exec, const QString& name )
 {
-  for ( PluginInfo *pl = plugins->first(); pl!=0; pl = plugins->next() ) {
-    if ( pl->name == name )
-      return new Plugin( exec, pl );
+  QList<const PluginInfo*>::const_iterator it, end = plugins->end();
+  for (it = plugins->begin(); it != end; ++it) {
+    if ((*it)->name == name)
+      return new Plugin(exec, *it);
   }
-  return Undefined();
+  return jsUndefined();
 }
 
-ValueImp *PluginsFunc::callAsFunction(ExecState *exec, ObjectImp *thisObj, const List &args)
+JSValue *PluginsFunc::callAsFunction(ExecState *exec, JSObject *thisObj, const List &args)
 {
   KJS_CHECK_THIS( KJS::Plugins, thisObj );
 
@@ -453,14 +465,14 @@ ValueImp *PluginsFunc::callAsFunction(ExecState *exec, ObjectImp *thisObj, const
 
   switch( id ) {
   case Plugins_Refresh:
-    return Undefined(); //## TODO
+    return jsUndefined(); //## TODO
   case Plugins_Item:
   {
     bool ok;
     unsigned int i = args[0]->toString(exec).toArrayIndex(&ok);
-    if( ok && i<base->plugins->count() )
+    if (ok && i < static_cast<unsigned>(base->plugins->count()))
       return new Plugin( exec, base->plugins->at(i) );
-    return Undefined();
+    return jsUndefined();
   }
   case Plugins_NamedItem:
   {
@@ -469,7 +481,7 @@ ValueImp *PluginsFunc::callAsFunction(ExecState *exec, ObjectImp *thisObj, const
   }
   default:
     kDebug(6070) << "WARNING: Unhandled token in PluginsFunc::callAsFunction : " << id;
-    return Undefined();
+    return jsUndefined();
   }
 }
 
@@ -485,12 +497,12 @@ const ClassInfo MimeTypes::info = { "MimeTypeArray", 0, &MimeTypesTable, 0 };
 */
 KJS_IMPLEMENT_PROTOFUNC(MimeTypesFunc)
 
-ValueImp *MimeTypes::indexGetter(ExecState *exec, JSObject*, const Identifier& propertyName, const PropertySlot& slot)
+JSValue *MimeTypes::indexGetter(ExecState* exec, JSObject*, const Identifier& /*propertyName*/, const PropertySlot& slot)
 {
   return new MimeType(exec, mimes->at(slot.index()));
 }
 
-ValueImp *MimeTypes::nameGetter(ExecState *exec, JSObject*, const Identifier& propertyName, const PropertySlot& slot)
+JSValue *MimeTypes::nameGetter(ExecState* exec, JSObject*, const Identifier& propertyName, const PropertySlot& /*slot*/)
 {
   return mimeTypeByName(exec, propertyName.qstring());
 }
@@ -507,14 +519,15 @@ bool MimeTypes::getOwnPropertySlot(ExecState *exec, const Identifier& propertyNa
     // mimeTypes[#]
     bool ok;
     unsigned int i = propertyName.toUInt32(&ok);
-    if (ok && i < mimes->count()) {
+    if (ok && i < static_cast<unsigned>(mimes->count())) {
       slot.setCustomIndex(this, i, indexGetter);
       return true;
     }
 
     // mimeTypes[name]
-    for (MimeClassInfo *m = mimes->first(); m; m = mimes->next()) {
-      if (m->type == propertyName.qstring()) {
+    QList<const MimeClassInfo*>::const_iterator it, end = mimes->end();
+    for (it = mimes->begin(); it != end; ++it) {
+      if ((*it)->type == propertyName.qstring()) {
         slot.setCustom(this, nameGetter);
         return true;
       }
@@ -524,26 +537,27 @@ bool MimeTypes::getOwnPropertySlot(ExecState *exec, const Identifier& propertyNa
   return PluginBase::getOwnPropertySlot(exec, propertyName, slot);
 }
 
-ValueImp *MimeTypes::mimeTypeByName( ExecState* exec, const QString& name )
+JSValue *MimeTypes::mimeTypeByName( ExecState* exec, const QString& name )
 {
   //kDebug(6070) << "MimeTypes[" << name << "]";
-  for ( MimeClassInfo *m = mimes->first(); m!=0; m = mimes->next() ) {
-    if ( m->type == name )
-      return new MimeType( exec, m );
+  QList<const MimeClassInfo*>::const_iterator it, end = mimes->end();
+  for (it = mimes->begin(); it != end; ++it) {
+    if ((*it)->type == name)
+      return new MimeType(exec, (*it));
   }
-  return Undefined();
+  return jsUndefined();
 }
 
-ValueImp *MimeTypes::getValueProperty(ExecState* /*exec*/, int token) const
+JSValue *MimeTypes::getValueProperty(ExecState* /*exec*/, int token) const
 {
   assert(token == MimeTypes_Length);
   if (pluginsEnabled())
-    return Number(mimes->count());
+    return jsNumber(mimes->count());
   else
-    return Number(0);
+    return jsNumber(0);
 }
 
-ValueImp *MimeTypesFunc::callAsFunction(ExecState *exec, ObjectImp *thisObj, const List &args)
+JSValue *MimeTypesFunc::callAsFunction(ExecState *exec, JSObject *thisObj, const List &args)
 {
   KJS_CHECK_THIS( KJS::MimeTypes, thisObj );
   KJS::MimeTypes* base = static_cast<KJS::MimeTypes *>(thisObj);
@@ -555,9 +569,9 @@ ValueImp *MimeTypesFunc::callAsFunction(ExecState *exec, ObjectImp *thisObj, con
   {
     bool ok;
     unsigned int i = args[0]->toString(exec).toArrayIndex(&ok);
-    if( ok && i<base->mimes->count() )
+    if (ok && i < static_cast<unsigned>(base->mimes->count()))
       return new MimeType( exec, base->mimes->at(i) );
-    return Undefined();
+    return jsUndefined();
   }
   case MimeTypes_NamedItem:
   {
@@ -566,7 +580,7 @@ ValueImp *MimeTypesFunc::callAsFunction(ExecState *exec, ObjectImp *thisObj, con
   }
   default:
     kDebug(6070) << "WARNING: Unhandled token in MimeTypesFunc::callAsFunction : " << id;
-    return Undefined();
+    return jsUndefined();
   }
 }
 
@@ -584,13 +598,13 @@ const ClassInfo Plugin::info = { "Plugin", 0, &PluginTable, 0 };
 */
 KJS_IMPLEMENT_PROTOFUNC(PluginFunc)
 
-ValueImp *Plugin::indexGetter(ExecState *exec, JSObject*, const Identifier& propertyName, const PropertySlot& slot)
+JSValue *Plugin::indexGetter(ExecState *exec, JSObject*, const Identifier& /*propertyName*/, const PropertySlot& slot)
 {
     Plugin *thisObj = static_cast<Plugin *>(slot.slotBase());
     return new MimeType(exec, thisObj->m_info->mimes.at(slot.index()));
 }
 
-ValueImp *Plugin::nameGetter(ExecState *exec, JSObject*, const Identifier& propertyName, const PropertySlot& slot)
+JSValue *Plugin::nameGetter(ExecState *exec, JSObject*, const Identifier& propertyName, const PropertySlot& slot)
 {
   Plugin *thisObj = static_cast<Plugin *>(slot.slotBase());
   return thisObj->mimeByName(exec, propertyName.qstring());
@@ -601,20 +615,21 @@ bool Plugin::getOwnPropertySlot(ExecState *exec, const Identifier& propertyName,
 #ifdef KJS_VERBOSE
   kDebug(6070) << "Plugin::getOwnPropertySlot " << propertyName.qstring();
 #endif
-  if (getStaticOwnPropertySlot<PluginFunc, Plugin>(&PluginsTable, this, propertyName, slot))
+  if (getStaticOwnPropertySlot<PluginFunc, Plugin>(&PluginTable, this, propertyName, slot))
       return true;
 
   // plugin[#]
   bool ok;
   unsigned int i = propertyName.toUInt32(&ok);
-  if (ok && i < m_info->mimes.count()) {
+  if (ok && i < static_cast<unsigned>(m_info->mimes.count())) {
     slot.setCustomIndex(this, i, indexGetter);
     return true;
   }
 
   // plugin["name"]
-  for (MimeClassInfo *m=m_info->mimes.first(); m; m = m_info->mimes.next()) {
-    if (m->type == propertyName.qstring()) {
+  QList<const MimeClassInfo*>::const_iterator it, end = mimes->end();
+  for (it = mimes->begin(); it != end; ++it) {
+    if ((*it)->type == propertyName.qstring()) {
       slot.setCustom(this, nameGetter);
       return true;
     }
@@ -623,34 +638,35 @@ bool Plugin::getOwnPropertySlot(ExecState *exec, const Identifier& propertyName,
   return PluginBase::getOwnPropertySlot(exec, propertyName, slot);
 }
 
-ValueImp *Plugin::mimeByName(ExecState* exec, const QString& name) const
+JSValue *Plugin::mimeByName(ExecState* exec, const QString& name) const
 {
-  for ( PluginBase::MimeClassInfo *m = m_info->mimes.first();
-        m != 0; m = m_info->mimes.next() ) {
-    if ( m->type == name )
-      return new MimeType(exec, m);
+  const QList<const MimeClassInfo*>& mimes = m_info->mimes;
+  QList<const MimeClassInfo*>::const_iterator it, end = mimes.end();
+  for (it = mimes.begin(); it != end; ++it) {
+    if ((*it)->type == name)
+      return new MimeType(exec, (*it));
   }
-  return Undefined();
+  return jsUndefined();
 }
 
-ValueImp *Plugin::getValueProperty(ExecState* /*exec*/, int token) const
+JSValue *Plugin::getValueProperty(ExecState* /*exec*/, int token) const
 {
   switch( token ) {
   case Plugin_Name:
-    return String( UString(m_info->name) );
+    return jsString( UString(m_info->name) );
   case Plugin_FileName:
-    return String( UString(m_info->file) );
+    return jsString( UString(m_info->file) );
   case Plugin_Description:
-    return String( UString(m_info->desc) );
+    return jsString( UString(m_info->desc) );
   case Plugin_Length:
-    return Number( m_info->mimes.count() );
+    return jsNumber( m_info->mimes.count() );
   default:
     kDebug(6070) << "WARNING: Unhandled token in Plugin::getValueProperty : " << token;
-    return Undefined();
+    return jsUndefined();
   }
 }
 
-ValueImp *PluginFunc::callAsFunction(ExecState *exec, ObjectImp *thisObj, const List &args)
+JSValue *PluginFunc::callAsFunction(ExecState *exec, JSObject *thisObj, const List &args)
 {
   KJS_CHECK_THIS( KJS::Plugin, thisObj );
   KJS::Plugin* plugin = static_cast<KJS::Plugin *>(thisObj);
@@ -659,9 +675,9 @@ ValueImp *PluginFunc::callAsFunction(ExecState *exec, ObjectImp *thisObj, const
   {
     bool ok;
     unsigned int i = args[0]->toString(exec).toArrayIndex(&ok);
-    if( ok && i< plugin->pluginInfo()->mimes.count() )
+    if (ok && i< static_cast<unsigned>(plugin->pluginInfo()->mimes.count()))
       return new MimeType( exec, plugin->pluginInfo()->mimes.at(i) );
-    return Undefined();
+    return jsUndefined();
   }
   case Plugin_NamedItem:
   {
@@ -670,13 +686,13 @@ ValueImp *PluginFunc::callAsFunction(ExecState *exec, ObjectImp *thisObj, const
   }
   default:
     kDebug(6070) << "WARNING: Unhandled token in PluginFunc::callAsFunction : " << id;
-    return Undefined();
+    return jsUndefined();
   }
 }
 
 /*****************************************************************************/
 
-const ClassInfo MimeType::info = { "MimeType", 0, &MimeTypesTable, 0 };
+const ClassInfo MimeType::info = { "MimeType", 0, &MimeTypeTable, 0 };
 /*
 @begin MimeTypeTable 4
   description  	MimeType_Description    	DontDelete|ReadOnly
@@ -691,31 +707,31 @@ bool MimeType::getOwnPropertySlot(ExecState *exec, const Identifier& propertyNam
 #ifdef KJS_VERBOSE
   kDebug(6070) << "MimeType::get " << propertyName.qstring();
 #endif
-  return getStaticValueSlot<MimeType, ObjectImp>(exec, &MimeTypesTable, this, propertyName, slot);
+  return getStaticValueSlot<MimeType, JSObject>(exec, &MimeTypeTable, this, propertyName, slot);
 }
 
-ValueImp *MimeType::getValueProperty(ExecState* exec, int token) const
+JSValue *MimeType::getValueProperty(ExecState* exec, int token) const
 {
   switch( token ) {
   case MimeType_Type:
-    return String( UString(m_info->type) );
+    return jsString( UString(m_info->type) );
   case MimeType_Suffixes:
-    return String( UString(m_info->suffixes) );
+    return jsString( UString(m_info->suffixes) );
   case MimeType_Description:
-    return String( UString(m_info->desc) );
+    return jsString( UString(m_info->desc) );
   case MimeType_EnabledPlugin:
     return new Plugin(exec, m_info->plugin);
   default:
     kDebug(6070) << "WARNING: Unhandled token in MimeType::getValueProperty : " << token;
-    return Undefined();
+    return jsUndefined();
   }
 }
 
 
-ValueImp *NavigatorFunc::callAsFunction(ExecState *exec, ObjectImp *thisObj, const List &)
+JSValue *NavigatorFunc::callAsFunction(ExecState *exec, JSObject *thisObj, const List &)
 {
   KJS_CHECK_THIS( KJS::Navigator, thisObj );
   Navigator *nav = static_cast<Navigator *>(thisObj);
   // javaEnabled()
-  return Boolean(nav->part()->javaEnabled());
+  return jsBoolean(nav->part()->javaEnabled());
 }
