@@ -184,12 +184,10 @@ void HTMLLinkElementImpl::process()
         part->browserExtension()->setIconUrl( KUrl(m_url.string()) );
 
     // Stylesheet
-    else if (!m_isDisabled &&
-        (type.contains("text/css") || rel.contains("stylesheet"))) {
+    else if (!m_isDisabled && rel.contains("stylesheet")) {
         // no need to load style sheets which aren't for the screen output
         // ### there may be in some situations e.g. for an editor or script to manipulate
         if( m_media.isNull() || m_media.contains("screen") || m_media.contains("all") || m_media.contains("print") ) {
-            m_loading = true;
             // Add ourselves as a pending sheet, but only if we aren't an alternate
             // stylesheet.  Alternate stylesheets don't hold up render tree construction.
             m_alternate = rel.contains("alternate");
@@ -200,8 +198,12 @@ void HTMLLinkElementImpl::process()
             // set chset to charset of referring document when attribute CHARSET is absent.
             // http://www.w3.org/TR/CSS21/syndata.html(4.4)
             if (chset.isEmpty() && part) chset = part->encoding();
-            if (m_cachedSheet)
+            if (m_cachedSheet) {
+                if (m_loading)
+                    getDocument()->styleSheetLoaded();
 		m_cachedSheet->deref(this);
+            }
+            m_loading = true;
             m_cachedSheet = getDocument()->docLoader()->requestStyleSheet(m_url, chset);
             if (m_cachedSheet) {
                 m_isCSSSheet = true;
@@ -209,6 +211,7 @@ void HTMLLinkElementImpl::process()
             }
             else if (!isAlternate()) {
                 // Error requesting sheet; decrement pending sheet count
+                m_loading = false;
                 getDocument()->styleSheetLoaded();
             }
         }
@@ -282,7 +285,16 @@ bool HTMLLinkElementImpl::isLoading() const
     return static_cast<CSSStyleSheetImpl *>(m_sheet)->isLoading();
 }
 
-bool HTMLLinkElementImpl::sheetLoaded()
+bool HTMLLinkElementImpl::checkAddPendingSheet()
+{
+    if (!isLoading() && !isDisabled() && !isAlternate()) {
+        getDocument()->addPendingSheet();
+        return true;
+    }
+    return false;
+}
+
+bool HTMLLinkElementImpl::checkRemovePendingSheet()
 {
     if (!isLoading() && !isDisabled() && !isAlternate()) {
         getDocument()->styleSheetLoaded();
@@ -637,7 +649,7 @@ bool HTMLStyleElementImpl::isLoading() const
     return static_cast<CSSStyleSheetImpl *>(m_sheet)->isLoading();
 }
 
-bool HTMLStyleElementImpl::sheetLoaded()
+bool HTMLStyleElementImpl::checkRemovePendingSheet()
 {
     if (!isLoading()) {
         getDocument()->styleSheetLoaded();
@@ -646,6 +658,15 @@ bool HTMLStyleElementImpl::sheetLoaded()
     return false;
 }
 
+bool HTMLStyleElementImpl::checkAddPendingSheet()
+{
+    if (!isLoading()) {
+        getDocument()->addPendingSheet();
+        return true;
+    }
+    return false;
+}
+
 // -------------------------------------------------------------------------
 
 NodeImpl::Id HTMLTitleElementImpl::id() const
