@@ -418,10 +418,14 @@ private:
     QMap< DOM::ElementImpl*, QChar > buildFallbackAccessKeys() const;
     void displayAccessKeys( KHTMLView* caller, KHTMLView* origview, QVector< QChar >& taken, bool use_fallbacks );
     bool isScrollingFromMouseWheel() const;
-    void setHasStaticBackground();
+    void setHasStaticBackground(bool partial=false);
+    void setHasNormalBackground();
+    void addStaticObject(bool fixed);
+    void removeStaticObject(bool fixed);
     void applyTransforms( int& x, int& y, int& w, int& h) const;
     void revertTransforms( int& x, int& y, int& w, int& h) const;
     void revertTransforms( int& x, int& y ) const;
+    void checkExternalWidgetsPosition();
 
     void setIgnoreWheelEvents(bool e);
 
@@ -448,6 +452,8 @@ private:
 
     void complete( bool pendingAction );
 
+    void updateScrollBars();
+
 #ifndef KHTML_NO_TYPE_AHEAD_FIND
     void findAhead(bool increase);
     void updateFindAheadTimeout();
