@@ -804,7 +804,11 @@ short RenderBox::containingBlockWidth() const
         //captions are not affected by table border or padding
         return cb->width();
     }
-    if (usesLineWidth())
+    if (isPositioned())
+        // cf. 10.1.4.2 - use padding edge
+        // ### FIXME: still wrong for inline CBs - 10.1.4.1
+        return cb->contentWidth() + cb->paddingLeft() + cb->paddingRight();
+    else if (usesLineWidth())
         return cb->lineWidth(m_y);
     else
         return cb->contentWidth();
@@ -1185,16 +1189,16 @@ int RenderBox::calcHeightUsing(const Length& h)
     return height;
 }
 
-int RenderBox::calcImplicitHeight() const {
+int RenderBox::calcImplicitContentHeight() const {
     assert(hasImplicitHeight());
 
     RenderBlock* cb = containingBlock();
     // padding-box height
-    int ch = cb->height() - cb->borderTop() + cb->borderBottom();
+    int ch = cb->height() - cb->borderTop() - cb->borderBottom();
     int top = style()->top().width(ch);
     int bottom = style()->bottom().width(ch);
 
-    return ch - top - bottom;
+    return ch - top - bottom - borderTop() - borderBottom() - paddingTop() - paddingBottom();;
 }
 
 int RenderBox::calcPercentageHeight(const Length& height, bool treatAsReplaced) const
@@ -1239,12 +1243,21 @@ int RenderBox::calcPercentageHeight(const Length& height, bool treatAsReplaced)
                               borderTop() + borderBottom() +
                               paddingTop() + paddingBottom());
     }
+    else if (isPositioned()) {
+        // "10.5 - Note that the height of the containing block of an absolutely positioned element is independent
+        //  of the size of the element itself, and thus a percentage height on such an element can always be resolved."
+        //
+        // take the used height - at the padding edge since we are positioned (10.1)
+        result = cb->height() - cb->borderTop() - cb->borderBottom();
+    }
     else if (cb->isAnonymousBlock() || treatAsReplaced && style()->htmlHacks()) {
         // IE quirk.
         result = cb->calcPercentageHeight(cb->style()->height(), treatAsReplaced);
+        if (result != -1)
+            result = cb->calcContentHeight(result);
     }
     else if (cb->hasImplicitHeight()) {
-        result = cb->calcImplicitHeight();
+        result = cb->calcImplicitContentHeight();
     }
 
     if (result != -1) {
@@ -1368,7 +1381,7 @@ int RenderBox::availableHeightUsing(const Length& h) const
 
     // Check for implicit height
     if (hasImplicitHeight())
-        return calcImplicitHeight();
+        return calcImplicitContentHeight();
 
     return containingBlock()->availableHeight();
 }
@@ -1455,9 +1468,7 @@ void RenderBox::calcAbsoluteHorizontal()
     // relative positioned inline.
     const RenderObject* containerBlock = container();
 
-    // FIXME: This is incorrect for cases where the container block is a relatively
-    // positioned inline.
-    const int containerWidth = containingBlockWidth() + containerBlock->paddingLeft() + containerBlock->paddingRight();
+    const int containerWidth = containingBlockWidth();
 
     // To match WinIE, in quirks mode use the parent's 'direction' property
     // instead of the the container block's.
@@ -1973,9 +1984,7 @@ void RenderBox::calcAbsoluteHorizontalReplaced()
     // We don't use containingBlock(), since we may be positioned by an enclosing relpositioned inline.
     const RenderObject* containerBlock = container();
 
-    // FIXME: This is incorrect for cases where the container block is a relatively
-    // positioned inline.
-    const int containerWidth = containingBlockWidth() + containerBlock->paddingLeft() + containerBlock->paddingRight();
+    const int containerWidth = containingBlockWidth();
 
     // To match WinIE, in quirks mode use the parent's 'direction' property
     // instead of the the container block's.
@@ -2355,7 +2364,7 @@ bool RenderBox::handleEvent(const DOM::EventImpl& e)
 
         QWheelEvent we(p, -me.detail()*40, buttons, state, orient);
         KHTMLAssert(layer());
-        KHTMLView* v = element()->getDocument()->view();
+        KHTMLView* v = document()->view();
         if ( ((orient == Qt::Vertical && (v->contentsHeight() > v->visibleHeight()))  ||
               (orient == Qt::Horizontal && (v->contentsWidth() > v->visibleWidth()))) &&
                v->isScrollingFromMouseWheel() ) {
