@@ -55,6 +55,8 @@ void RenderContainer::addChild(RenderObject *newChild, RenderObject *beforeChild
     kDebug( 6040 ) << this << ": " <<  renderName() << "(RenderObject)::addChild( " << newChild << ": " <<
         newChild->renderName() << ", " << (beforeChild ? beforeChild->renderName() : "0") << " )" << endl;
 #endif
+    // protect ourselves from deletion
+    setDoNotDelete(true);
 
     bool needsTable = false;
 
@@ -135,6 +137,8 @@ void RenderContainer::addChild(RenderObject *newChild, RenderObject *beforeChild
             static_cast<RenderText*>(newChild)->setText(textToTransform, true);
     }
     newChild->attach();
+    
+    setDoNotDelete(false);
 }
 
 RenderObject* RenderContainer::removeChildNode(RenderObject* oldChild)
@@ -176,6 +180,14 @@ RenderObject* RenderContainer::removeChildNode(RenderObject* oldChild)
         }
         // remove the child from any special layout lists
         oldChild->removeFromObjectLists();
+
+        // keep our fixed object lists updated.
+        if (oldChild->style()->hasFixedBackgroundImage() || oldChild->style()->position() == FIXED) {
+            if (oldChild->style()->hasFixedBackgroundImage())
+                canvas()->removeStaticObject( oldChild );
+            if (oldChild->style()->position() == FIXED)
+                canvas()->removeStaticObject( oldChild, true );
+        }
         
         if (oldChild->isPosWithStaticDim() && childrenInline())
             dirtyLinesFromChangedChild(oldChild);
@@ -479,6 +491,13 @@ void RenderContainer::appendChildNode(RenderObject* newChild)
     if (newChild->firstChild() || newChild->layer()) {
         layer = enclosingLayer();
         newChild->addLayers(layer, newChild);
+        // keep our fixed object lists updated.
+        if (newChild->style()&& (newChild->style()->hasFixedBackgroundImage() || newChild->style()->position() == FIXED)) {
+            if (newChild->style()->hasFixedBackgroundImage())
+                canvas()->addStaticObject( newChild );
+            if (newChild->style()->position() == FIXED)
+                canvas()->addStaticObject( newChild, true );
+        }
     }
 
     // if the new child is visible but this object was not, tell the layer it has some visible content
@@ -532,6 +551,14 @@ void RenderContainer::insertChildNode(RenderObject* child, RenderObject* beforeC
     if (child->firstChild() || child->layer()) {
         layer = enclosingLayer();
         child->addLayers(layer, child);
+        // keep our fixed object lists updated.
+        if (child->style() && (child->style()->hasFixedBackgroundImage() || child->style()->position() == FIXED)) {
+            if (child->style()->hasFixedBackgroundImage())
+                canvas()->addStaticObject( child );
+            if (child->style()->position() == FIXED)
+                canvas()->addStaticObject( child, true );
+        }
+
     }
 
     // if the new child is visible but this object was not, tell the layer it has some visible content
@@ -583,7 +610,7 @@ void RenderContainer::removeLeftoverAnonymousBoxes()
 	RenderObject *next = child->nextSibling();
 
 	if ( child->isRenderBlock() && child->isAnonymousBlock() && !child->continuation() &&
-             !child->childrenInline() && !child->isTableCell() ) {
+             !child->childrenInline() && !child->isTableCell() && !child->doNotDelete()) {
 	    RenderObject *firstAnChild = child->firstChild();
 	    RenderObject *lastAnChild = child->lastChild();
 	    if ( firstAnChild ) {
@@ -598,17 +625,21 @@ void RenderContainer::removeLeftoverAnonymousBoxes()
 		    child->previousSibling()->setNextSibling( firstAnChild );
 		if ( child->nextSibling() )
 		    child->nextSibling()->setPreviousSibling( lastAnChild );
+		if ( child == firstChild() )
+		    m_first = firstAnChild;
+		if ( child == lastChild() )
+		    m_last = lastAnChild;
 	    } else {
 		if ( child->previousSibling() )
 		    child->previousSibling()->setNextSibling( child->nextSibling() );
 		if ( child->nextSibling() )
 		    child->nextSibling()->setPreviousSibling( child->previousSibling() );
-
+		if ( child == firstChild() )
+		    m_first = child->nextSibling();
+		if ( child == lastChild() )
+		    m_last = child->previousSibling();
 	    }
-	    if ( child == firstChild() )
-		m_first = firstAnChild;
-	    if ( child == lastChild() )
-		m_last = lastAnChild;
+
 	    child->setParent( 0 );
 	    child->setPreviousSibling( 0 );
 	    child->setNextSibling( 0 );
