@@ -211,12 +211,27 @@ void  RenderWidget::resizeWidget( int w, int h )
     w = qMin( w, 2000 );
 
     if (m_widget->width() != w || m_widget->height() != h) {
-        m_resizePending = isRedirectedWidget();
-        ref();
-        element()->ref();
-        QApplication::postEvent( this, new QWidgetResizeEvent( w, h ) );
-        element()->deref();
-        deref();
+        if (isRedirectedWidget() && qobject_cast<KHTMLView*>(m_widget)) {
+             m_widget->resize( w, h);
+             if (!m_widget->isVisible()) {
+                 // Emission of Resize event is delayed.
+                 // we have to pre-call KHTMLView::resizeEvent
+                 // so that viewport size change and subsequent layout update
+                 // is effective synchronously, which is important for JS.
+                 // This only work because m_widget is a redirected view,
+                 // and thus has visibleWidth()/visibleHeight() that mirror this RenderWidget,
+                 // rather than the effective widget size. - gg.
+                 QResizeEvent e( QSize(w,h), QSize(m_widget->width(),m_widget->height()));
+                 static_cast<KHTMLView*>(m_widget)->resizeEvent( &e );
+             }
+        } else {
+            m_resizePending = isRedirectedWidget();
+            ref();
+            element()->ref();
+            QApplication::postEvent( this, new QWidgetResizeEvent( w, h ) );
+            element()->deref();
+            deref();
+        }
     }
 }
 
@@ -569,6 +584,14 @@ static void setInPaintEventFlag(QWidget* w, bool b = true, bool recurse=true)
       }
 }
 
+static bool qtVersionDetected = false;
+static bool qt43;
+
+static void detectQtVersion() {
+    qtVersionDetected = true;
+    qt43 = QString::fromLatin1(qVersion()).startsWith("4.3");
+}
+
 static void copyWidget(const QRect& r, QPainter *p, QWidget *widget, int tx, int ty, bool buffered = false)
 {
     if (r.isNull() || r.isEmpty() )
@@ -589,25 +612,40 @@ static void copyWidget(const QRect& r, QPainter *p, QWidget *widget, int tx, int
     QPaintDevice *x = d;
     qreal op = p->opacity();
     QPixmap* pm = 0;
+    QPen pen = p->pen();
+    QBrush brush = p->brush();
     if (buffered) {
         if (!widget->size().isValid())
             return;
         pm = PaintBuffer::grab(widget->size());
-        QPainter pp(pm);
-        pp.setCompositionMode(QPainter::CompositionMode_Clear);
-        pp.eraseRect(r);
+        // Qt 4.4 regression #1:
+        // QPainter::CompositionMode_Source is severly broken (cf. kde #160518)
+        //
+        if (1 || !pm->hasAlphaChannel()) {
+            pm->fill(Qt::transparent);
+        } else {
+            QPainter pp(pm);
+            pp.setCompositionMode( QPainter::CompositionMode_Source );
+            pp.fillRect(r, Qt::transparent);
+        }
         d = pm;
-    } else {
-        p->end();
     }
+    // Qt 4.4 regression #2: 
+    // can't let a painter active on the view as Qt thinks it is opened on the *pixmap*
+    // and prints "paint device can only be painted by one painter at a time" warnings.
+    //
+    // Testcase: paintEvent(...) { QPainter p(this); aChildWidget->render( aPixmapTarget, ...); }
+    //
+    if (!qt43 || !buffered)
+        p->end();
 
     setInPaintEventFlag( widget, false );
 
-    widget->render( d, (buffered ? QPoint(0,0) : thePoint), r);
+    widget->render( d, (buffered ? QPoint(0,0) : thePoint) + (qt43 ? QPoint(0,0) : r.topLeft()), r);
 
     setInPaintEventFlag( widget );
 
-    if (!buffered) {
+    if (!qt43 || !buffered) {
         p->begin(x);
         p->setWorldTransform(t);
         p->setWindow(w);
@@ -618,7 +656,10 @@ static void copyWidget(const QRect& r, QPainter *p, QWidget *widget, int tx, int
             p->setClipRegion(rg);
         if (op < 1.0f)
             p->setOpacity(op);
-    } else {
+        p->setPen(pen);
+        p->setBrush(brush);
+    }
+    if (buffered) {
         // transfer results
         QPoint off(r.x(), r.y());
         p->drawPixmap(thePoint+off, static_cast<QPixmap&>(*d), r);
@@ -631,7 +672,13 @@ void RenderWidget::paintWidget(PaintInfo& pI, QWidget *widget, int tx, int ty)
     QPainter* const p = pI.p;
     allowWidgetPaintEvents = true;
 
-    bool buffered = p->combinedMatrix().m22() != 1.0 || (p->device()->devType() == QInternal::Printer);
+    // Qt 4.4 regression #3: 
+    //    can't use QWidget::render to directly paint widgets on the view anymore.
+    //    Results are unreliable for subrects, leaving blank squares. (cf. kde #158607)
+    //
+    if (!qtVersionDetected)
+        detectQtVersion();
+    bool buffered = !qt43 || p->combinedMatrix().m22() != 1.0 || (p->device()->devType() == QInternal::Printer);
 
     QRect rr = pI.r;
     rr.translate(-tx, -ty);
@@ -708,7 +755,7 @@ bool RenderWidget::eventFilter(QObject* /*o*/, QEvent* e)
         filtered       = true; //We already delivered it!
 
         //kDebug(6000) << "RenderWidget::eventFilter captures FocusIn";
-        element()->getDocument()->setFocusNode(element());
+        document()->setFocusNode(element());
 //         if ( isEditable() ) {
 //             KHTMLPartBrowserExtension *ext = static_cast<KHTMLPartBrowserExtension *>( element()->view->part()->browserExtension() );
 //             if ( ext )  ext->editableWidgetFocused( m_widget );
