@@ -90,8 +90,10 @@ void InlineTextBox::operator delete(void* ptr, size_t sz)
 {
     assert(inInlineTextBoxDetach);
 
+#ifdef KHTML_USE_ARENA_ALLOCATOR
     // Stash size where detach can find it.
     *(size_t *)ptr = sz;
+#endif
 }
 
 void InlineTextBox::selectionStartEnd(int& sPos, int& ePos)
@@ -1202,7 +1204,7 @@ void RenderText::setText(DOMStringImpl *text, bool force)
     KHTMLAssert(!isBR() || (str->l == 1 && (*str->s) == '\n'));
     KHTMLAssert(!str->l || str->s);
 
-    setNeedsLayoutAndMinMaxRecalc();
+    if (parent()) setNeedsLayoutAndMinMaxRecalc();
 #ifdef BIDI_DEBUG
     QString cstr = QString::fromRawData(str->s, str->l);
     kDebug( 6040 ) << "RenderText::setText( " << cstr.length() << " ) '" << cstr << "'";
