@@ -176,11 +176,15 @@ DocumentImpl *DOMImplementationImpl::createDocument( const DOMString &namespaceU
 
     // ### this is completely broken.. without a view it will not work (Dirk)
     DocumentImpl *doc = new DocumentImpl(this, 0);
-
-    // now get the interesting parts of the doctype
-    // ### create new one if not there (currently always there)
-    if (doc->doctype() && dtype)
-        doc->doctype()->copyFrom(*dtype);
+    if (dtype) {
+        doc->setDocType(dtype);
+    } else {
+        // ### this should be created during parsing a <!DOCTYPE>
+        doc->setDocType(new DocumentTypeImpl(this, doc,
+                                             DOMString() /* qualifiedName */,
+                                             DOMString() /* publicId */,
+                                             DOMString() /* systemId */));
+    }
 
     // the document must be created empty if all parameters are null
     // (or empty for qName/nsURI as a tolerance) - see DOM 3 Core.
@@ -209,12 +213,24 @@ CSSStyleSheetImpl *DOMImplementationImpl::createCSSStyleSheet(DOMStringImpl* /*t
 
 DocumentImpl *DOMImplementationImpl::createDocument( KHTMLView *v )
 {
-    return new DocumentImpl(this, v);
+    DocumentImpl* doc = new DocumentImpl(this, v);
+    // ### this should be created during parsing a <!DOCTYPE>
+    doc->setDocType(new DocumentTypeImpl(doc->implementation(), doc,
+                                         DOMString() /* qualifiedName */,
+                                         DOMString() /* publicId */,
+                                         DOMString() /* systemId */));
+    return doc;
 }
 
 HTMLDocumentImpl *DOMImplementationImpl::createHTMLDocument( KHTMLView *v )
 {
-    return new HTMLDocumentImpl(this, v);
+    HTMLDocumentImpl* doc = new HTMLDocumentImpl(this, v);
+    // ### this should be created during parsing a <!DOCTYPE>
+    doc->setDocType(new DocumentTypeImpl(doc->implementation(), doc,
+                                         DOMString() /* qualifiedName */,
+                                         DOMString() /* publicId */,
+                                         DOMString() /* systemId */));
+    return doc;
 }
 
 HTMLDocumentImpl* DOMImplementationImpl::createHTMLDocument( const DOMString& title )
@@ -341,15 +357,7 @@ DocumentImpl::DocumentImpl(DOMImplementationImpl *_implementation, KHTMLView *v)
     m_docChanged = false;
     m_elemSheet = 0;
     m_tokenizer = 0;
-
-    // ### this should be created during parsing a <!DOCTYPE>
-    // not during construction. Not sure who added that and why (Dirk)
-    m_doctype = new DocumentTypeImpl(_implementation, getDocument(),
-                                     DOMString() /* qualifiedName */,
-                                     DOMString() /* publicId */,
-                                     DOMString() /* systemId */);
-    m_doctype->ref();
-
+    m_doctype = 0;
     m_implementation = _implementation;
     m_implementation->ref();
     pMode = Strict;
@@ -499,6 +507,14 @@ DocumentTypeImpl *DocumentImpl::doctype() const
     return m_doctype;
 }
 
+void DocumentImpl::setDocType(DocumentTypeImpl* dt)
+{
+    assert(m_doctype == 0 && dt != 0);
+    m_doctype = dt;
+    m_doctype->ref();
+    m_doctype->setDocument(this);
+}
+
 DOMImplementationImpl *DocumentImpl::implementation() const
 {
     return m_implementation;
@@ -2053,6 +2069,11 @@ void DocumentImpl::styleSheetLoaded()
   updateStyleSelector();
 }
 
+void DocumentImpl::addPendingSheet()
+{
+     m_pendingStylesheets++;
+}
+
 DOMString DocumentImpl::selectedStylesheetSet() const
 {
     if (!view()) return DOMString();
@@ -2619,7 +2640,7 @@ void DocumentImpl::defaultEventHandler(EventImpl *evt)
             if (!m_windowEventListeners.stillContainsListener(*it))
                 continue;
 
-            if ((*it).id == evt->id()) {
+            if ((*it).eventName == evt->name()) {
                 // currentTarget must be 0 in khtml for kjs_events to set "this" correctly.
                 // (this is how we identify events dispatched to the window, like window.onmousedown)
                 // ## currentTarget is unimplemented in IE, and is "window" in Mozilla (how? not a DOM node)
@@ -2632,27 +2653,37 @@ void DocumentImpl::defaultEventHandler(EventImpl *evt)
         contentLoaded();
 }
 
-void DocumentImpl::setHTMLWindowEventListener(int id, EventListener *listener)
+void DocumentImpl::setHTMLWindowEventListener(EventName id, EventListener *listener)
 {
     m_windowEventListeners.setHTMLEventListener(id, listener);
 }
 
-EventListener *DocumentImpl::getHTMLWindowEventListener(int id)
+void DocumentImpl::setHTMLWindowEventListener(unsigned id, EventListener *listener)
+{
+    m_windowEventListeners.setHTMLEventListener(EventName::fromId(id), listener);
+}
+
+EventListener *DocumentImpl::getHTMLWindowEventListener(EventName id)
 {
     return m_windowEventListeners.getHTMLEventListener(id);
 }
 
-void DocumentImpl::addWindowEventListener(int id, EventListener *listener, const bool useCapture)
+EventListener *DocumentImpl::getHTMLWindowEventListener(unsigned id)
+{
+    return m_windowEventListeners.getHTMLEventListener(EventName::fromId(id));
+}
+
+void DocumentImpl::addWindowEventListener(EventName id, EventListener *listener, const bool useCapture)
 {
     m_windowEventListeners.addEventListener(id, listener, useCapture);
 }
 
-void DocumentImpl::removeWindowEventListener(int id, EventListener *listener, bool useCapture)
+void DocumentImpl::removeWindowEventListener(EventName id, EventListener *listener, bool useCapture)
 {
     m_windowEventListeners.removeEventListener(id, listener, useCapture);
 }
 
-bool DocumentImpl::hasWindowEventListener(int id)
+bool DocumentImpl::hasWindowEventListener(EventName id)
 {
     return m_windowEventListeners.hasEventListener(id);
 }
@@ -2910,14 +2941,6 @@ DocumentTypeImpl::~DocumentTypeImpl()
         m_notations->deref();
 }
 
-void DocumentTypeImpl::copyFrom(const DocumentTypeImpl& other)
-{
-    m_qualifiedName = other.m_qualifiedName;
-    m_publicId = other.m_publicId;
-    m_systemId = other.m_systemId;
-    m_subset = other.m_subset;
-}
-
 DOMString DocumentTypeImpl::toString() const
 {
     DOMString result = "<!DOCTYPE";
