@@ -189,6 +189,7 @@ public:
     // DOM methods & attributes for Document
 
     DocumentTypeImpl *doctype() const;
+    void setDocType(DocumentTypeImpl* dt);
 
     DOMImplementationImpl *implementation() const;
     ElementImpl *documentElement() const;
@@ -243,7 +244,7 @@ public:
      * Increments the number of pending sheets.  The \<link\> elements
      * invoke this to add themselves to the loading list.
      */
-    void addPendingSheet() { m_pendingStylesheets++; }
+    void addPendingSheet();
 
     /**
      * Returns true if the document has pending stylesheets
@@ -451,13 +452,18 @@ public:
     LocalStyleRefs* localStyleRefs() { return &m_localStyleRefs; }
 
     virtual void defaultEventHandler(EventImpl *evt);
-    virtual void setHTMLWindowEventListener(int id, EventListener *listener);
-    EventListener *getHTMLWindowEventListener(int id);
+
+    void setHTMLWindowEventListener(EventName id, EventListener *listener);
+    void setHTMLWindowEventListener(unsigned id, EventListener *listener);
+
+    EventListener *getHTMLWindowEventListener(EventName id);
+    EventListener *getHTMLWindowEventListener(unsigned id);
+
     EventListener *createHTMLEventListener(const QString& code, const QString& name, NodeImpl* node);
 
-    void addWindowEventListener(int id, EventListener *listener, const bool useCapture);
-    void removeWindowEventListener(int id, EventListener *listener, bool useCapture);
-    bool hasWindowEventListener(int id);
+    void addWindowEventListener(EventName id, EventListener *listener, const bool useCapture);
+    void removeWindowEventListener(EventName id, EventListener *listener, bool useCapture);
+    bool hasWindowEventListener(EventName id);
 
     EventListener *createHTMLEventListener(QString code);
 
@@ -738,7 +744,6 @@ public:
     void setPublicId(const DOMString& publicId) { m_publicId = publicId; }
     void setSystemId(const DOMString& systemId) { m_systemId = systemId; }
     DOMImplementationImpl *implementation() const { return m_implementation; }
-    void copyFrom(const DocumentTypeImpl&);
 
     virtual DOMString toString() const;
 
