@@ -165,6 +165,8 @@ IdleSlave::age(time_t now)
    return (int) difftime(now, mBirthDate);
 }
 
+static KLauncher* g_klauncher_self;
+
 KLauncher::KLauncher(int _kdeinitSocket)
   : QObject(0),
     kdeinitSocket(_kdeinitSocket), dontBlockReading(false)
@@ -172,6 +174,9 @@ KLauncher::KLauncher(int _kdeinitSocket)
 #ifdef Q_WS_X11
    mCached_dpy = NULL;
 #endif
+   Q_ASSERT( g_klauncher_self == NULL );
+   g_klauncher_self = this;
+
    mAutoTimer.setSingleShot(true);
    new KLauncherAdaptor(this);
    QDBusConnection::sessionBus().registerObject("/KLauncher", this); // same as ktoolinvocation.cpp
@@ -225,22 +230,27 @@ KLauncher::KLauncher(int _kdeinitSocket)
 KLauncher::~KLauncher()
 {
    close();
+   g_klauncher_self = NULL;
 }
 
 void KLauncher::close()
 {
 #ifdef Q_WS_X11
    if( mCached_dpy != NULL )
+   {
        XCloseDisplay( mCached_dpy );
+       mCached_dpy = NULL;
+   }
 #endif
 }
 
 void
-KLauncher::destruct(int exit_code)
+KLauncher::destruct()
 {
-    if (QCoreApplication::instance()) ((KLauncher*)QCoreApplication::instance())->close();
+    if (g_klauncher_self)
+        g_klauncher_self->close();
     // We don't delete the app here, that's intentional.
-    ::_exit(exit_code);
+    ::_exit(255);
 }
 
 void KLauncher::setLaunchEnv(const QString &name, const QString &value)
@@ -312,7 +322,7 @@ KLauncher::slotKDEInitData(int)
       kDebug(7016) << "Exiting on read_socket errno:" << errno;
       ::signal( SIGHUP, SIG_IGN);
       ::signal( SIGTERM, SIG_IGN);
-      destruct(255); // Exit!
+      destruct(); // Exit!
    }
    requestData.resize(request_header.arg_length);
    result = read_socket(kdeinitSocket, (char *) requestData.data(),
