@@ -1109,7 +1109,11 @@ void CopyJobPrivate::slotResultCopyingFiles( KJob * job )
 
     //kDebug(7007) << files.count() << " files remaining";
 
-    q->removeSubjob( job, true ); // merge metadata
+    // Merge metadata from subjob
+    KIO::Job* kiojob = dynamic_cast<KIO::Job*>(job);
+    Q_ASSERT(kiojob);
+    m_incomingMetaData += kiojob->metaData();
+    q->removeSubjob( job );
     assert( !q->hasSubjobs() ); // We should have only one job at a time ...
     copyNextFile();
 }
@@ -1281,13 +1285,13 @@ KIO::Job* CopyJobPrivate::linkNextFile( const KUrl& uSource, const KUrl& uDest,
                 config.writeEntry( "Type", QString::fromLatin1("Link") );
                 QString protocol = uSource.protocol();
                 if ( protocol == QLatin1String("ftp") )
-                    config.writeEntry( "Icon", QString::fromLatin1("ftp") );
+                    config.writeEntry( "Icon", QString::fromLatin1("folder-remote") );
                 else if ( protocol == QLatin1String("http") )
-                    config.writeEntry( "Icon", QString::fromLatin1("www") );
+                    config.writeEntry( "Icon", QString::fromLatin1("text-html") );
                 else if ( protocol == QLatin1String("info") )
-                    config.writeEntry( "Icon", QString::fromLatin1("info") );
+                    config.writeEntry( "Icon", QString::fromLatin1("text-x-texinfo") );
                 else if ( protocol == QLatin1String("mailto") )   // sven:
-                    config.writeEntry( "Icon", QString::fromLatin1("kmail") ); // added mailto: support
+                    config.writeEntry( "Icon", QString::fromLatin1("internet-mail") ); // added mailto: support
                 else
                     config.writeEntry( "Icon", QString::fromLatin1("unknown") );
                 config.sync();
@@ -1577,7 +1581,11 @@ void CopyJobPrivate::slotResultRenaming( KJob* job )
     Q_Q(CopyJob);
     int err = job->error();
     const QString errText = job->errorText();
-    q->removeSubjob( job, true ); // merge metadata
+    // Merge metadata from subjob
+    KIO::Job* kiojob = dynamic_cast<KIO::Job*>(job);
+    Q_ASSERT(kiojob);
+    m_incomingMetaData += kiojob->metaData();
+    q->removeSubjob( job );
     assert ( !q->hasSubjobs() );
     // Determine dest again
     KUrl dest = m_dest;
