@@ -1506,7 +1506,7 @@ StoredTransferJob *KIO::storedPut( const QByteArray& arr, const KUrl& url, int p
                                    JobFlags flags )
 {
     KIO_ARGS << url << qint8( (flags & Overwrite) ? 1 : 0 ) << qint8( (flags & Resume) ? 1 : 0 ) << permissions;
-    StoredTransferJob * job = StoredTransferJobPrivate::newJob(url, CMD_GET, packedArgs, flags );
+    StoredTransferJob * job = StoredTransferJobPrivate::newJob(url, CMD_PUT, packedArgs, flags );
     job->setData( arr );
     return job;
 }
