@@ -432,7 +432,8 @@ bool Ftp::ftpLogin()
   AuthInfo info;
   info.url.setProtocol( "ftp" );
   info.url.setHost( m_host );
-  info.url.setPort( m_port );
+  if ( m_port > 0 && m_port != DEFAULT_FTP_PORT )
+      info.url.setPort( m_port );
   info.url.setUser( user );
 
   QByteArray tempbuf;
@@ -1381,7 +1382,8 @@ void Ftp::listDir( const KUrl &url )
     if ( m_pass != FTP_PASSWD )
       realURL.setPass( m_pass );
     realURL.setHost( m_host );
-    realURL.setPort( m_port );
+    if ( m_port > 0 && m_port != DEFAULT_FTP_PORT )
+        realURL.setPort( m_port );
     if ( m_initialPath.isEmpty() )
         m_initialPath = "/";
     realURL.setPath( m_initialPath );
@@ -2327,7 +2329,13 @@ Ftp::StatusCode Ftp::ftpCopyGet(int& iError, int& iCopyFile, const QString &sCop
   {
     if(iRes == statusSuccess)
     { // rename ".part" on success
+#ifdef Q_OS_WIN
+        if ( MoveFileExA( sPart.data(),
+                          sDest.data(),
+                          MOVEFILE_REPLACE_EXISTING|MOVEFILE_COPY_ALLOWED ) == 0 )
+#else
       if ( ::rename( sPart.data(), sDest.data() ) )
+#endif
       {
         kDebug(7102) << "copy: cannot rename " << sPart << " to " << sDest;
         iError = ERR_CANNOT_RENAME_PARTIAL;
