@@ -354,14 +354,12 @@ void Interpreter::initGlobalObject()
     m_globalObject->put(&m_globalExec, "Date", m_Date, DontEnum);
     m_globalObject->put(&m_globalExec, "RegExp", m_RegExp, DontEnum);
     m_globalObject->put(&m_globalExec, "Error", m_Error, DontEnum);
-    // Using Internal for those to have something != 0
-    // (see kjs_window). Maybe DontEnum would be ok too ?
-    m_globalObject->put(&m_globalExec, "EvalError",m_EvalError, Internal);
-    m_globalObject->put(&m_globalExec, "RangeError",m_RangeError, Internal);
-    m_globalObject->put(&m_globalExec, "ReferenceError",m_ReferenceError, Internal);
-    m_globalObject->put(&m_globalExec, "SyntaxError",m_SyntaxError, Internal);
-    m_globalObject->put(&m_globalExec, "TypeError",m_TypeError, Internal);
-    m_globalObject->put(&m_globalExec, "URIError",m_UriError, Internal);
+    m_globalObject->put(&m_globalExec, "EvalError",m_EvalError, DontEnum);
+    m_globalObject->put(&m_globalExec, "RangeError",m_RangeError, DontEnum);
+    m_globalObject->put(&m_globalExec, "ReferenceError",m_ReferenceError, DontEnum);
+    m_globalObject->put(&m_globalExec, "SyntaxError",m_SyntaxError, DontEnum);
+    m_globalObject->put(&m_globalExec, "TypeError",m_TypeError, DontEnum);
+    m_globalObject->put(&m_globalExec, "URIError",m_UriError, DontEnum);
     
     // Set the constructorPropertyName property of all builtin constructors
     objProto->put(&m_globalExec, m_globalExec.propertyNames().constructor, m_Object, DontEnum | DontDelete | ReadOnly);
@@ -431,7 +429,7 @@ Completion Interpreter::checkSyntax(const UString& sourceURL, int startingLineNu
 
     int errLine;
     UString errMsg;
-    RefPtr<ProgramNode> progNode = Parser::parse(sourceURL, startingLineNumber, code, codeLength, 0, &errLine, &errMsg);
+    RefPtr<ProgramNode> progNode = parser().parseProgram(sourceURL, startingLineNumber, code, codeLength, 0, &errLine, &errMsg);
     if (!progNode)
         return Completion(Throw, Error::create(&m_globalExec, SyntaxError, errMsg, errLine, 0, sourceURL));
     return Completion(Normal);
@@ -451,21 +449,21 @@ Completion Interpreter::evaluate(const UString& sourceURL, int startingLineNumbe
         return Completion(Throw, Error::create(&m_globalExec, GeneralError, "Recursion too deep"));
     
     // parse the source code
-    int sid;
+    int sourceId;
     int errLine;
     UString errMsg;
-    RefPtr<ProgramNode> progNode = Parser::parse(sourceURL, startingLineNumber, code, codeLength, &sid, &errLine, &errMsg);
+    RefPtr<ProgramNode> progNode = parser().parseProgram(sourceURL, startingLineNumber, code, codeLength, &sourceId, &errLine, &errMsg);
     
     // notify debugger that source has been parsed
     if (m_debugger) {
-        bool cont = m_debugger->sourceParsed(&m_globalExec, sid, sourceURL, UString(code, codeLength), startingLineNumber, errLine, errMsg);
+        bool cont = m_debugger->sourceParsed(&m_globalExec, sourceId, sourceURL, UString(code, codeLength), startingLineNumber, errLine, errMsg);
         if (!cont)
             return Completion(Break);
     }
     
     // no program node means a syntax error occurred
     if (!progNode) {
-        Completion res(Throw, Error::create(&m_globalExec, SyntaxError, errMsg, errLine, sid, sourceURL));
+        Completion res(Throw, Error::create(&m_globalExec, SyntaxError, errMsg, errLine, sourceId, sourceURL));
 	if (shouldPrintExceptions())
 	  printException(res, sourceURL);
 	return res;
@@ -491,7 +489,7 @@ Completion Interpreter::evaluate(const UString& sourceURL, int startingLineNumbe
         Context ctx(globalObj, this, thisObj, progNode.get());
         ExecState newExec(this, &ctx);
 
-        if (m_debugger && !m_debugger->enterContext(&newExec, sid, startingLineNumber, 0, List::empty())) {
+        if (m_debugger && !m_debugger->enterContext(&newExec, sourceId, startingLineNumber, 0, List::empty())) {
             // debugger requested we stop execution.
             m_debugger->imp()->abort();
             return Completion(Break);
@@ -500,7 +498,7 @@ Completion Interpreter::evaluate(const UString& sourceURL, int startingLineNumbe
         progNode->processDecls(&newExec);
         res = progNode->execute(&newExec);
 
-        if (m_debugger && !m_debugger->exitContext(&newExec, sid, startingLineNumber, 0)) {
+        if (m_debugger && !m_debugger->exitContext(&newExec, sourceId, startingLineNumber, 0)) {
             // debugger requested we stop execution.
             m_debugger->imp()->abort();
             return Completion(Break);
@@ -693,8 +691,6 @@ void Interpreter::finalCheck()
 
 //  Node::finalCheck();
   Collector::finalCheck();
-  Lexer::globalClear();
-  UString::globalClear();
 }
 #endif
 
